# Autogenerated by nbdev

d = {
    "settings": {
        "branch": "main",
        "doc_baseurl": "/domo_library",
        "doc_host": "https://jaewilson07.github.io",
        "git_url": "https://github.com/jaewilson07/domo_library",
        "lib_path": "domolibrary",
    },
    "syms": {
        "domolibrary.classes.DomoAccessToken": {
            "domolibrary.classes.DomoAccessToken.DomoAccessToken": (
                "classes/domoaccesstoken.html#domoaccesstoken",
                "domolibrary/classes/DomoAccessToken.py",
            ),
            "domolibrary.classes.DomoAccessToken.DomoAccessToken.__eq__": (
                "classes/domoaccesstoken.html#domoaccesstoken.__eq__",
                "domolibrary/classes/DomoAccessToken.py",
            ),
            "domolibrary.classes.DomoAccessToken.DomoAccessToken._from_json": (
                "classes/domoaccesstoken.html#domoaccesstoken._from_json",
                "domolibrary/classes/DomoAccessToken.py",
            ),
            "domolibrary.classes.DomoAccessToken.DomoAccessToken.generate": (
                "classes/domoaccesstoken.html#domoaccesstoken.generate",
                "domolibrary/classes/DomoAccessToken.py",
            ),
            "domolibrary.classes.DomoAccessToken.DomoAccessToken.regenerate": (
                "classes/domoaccesstoken.html#domoaccesstoken.regenerate",
                "domolibrary/classes/DomoAccessToken.py",
            ),
            "domolibrary.classes.DomoAccessToken.DomoAccessToken.revoke": (
                "classes/domoaccesstoken.html#domoaccesstoken.revoke",
                "domolibrary/classes/DomoAccessToken.py",
            ),
            "domolibrary.classes.DomoAccessToken.get_access_tokens": (
                "classes/domoaccesstoken.html#get_access_tokens",
                "domolibrary/classes/DomoAccessToken.py",
            ),
        },
        "domolibrary.classes.DomoAccount": {
            "domolibrary.classes.DomoAccount.Account_Accesslist": (
                "classes/domoaccount.html#account_accesslist",
                "domolibrary/classes/DomoAccount.py",
            ),
            "domolibrary.classes.DomoAccount.Account_Accesslist_Share": (
                "classes/domoaccount.html#account_accesslist_share",
                "domolibrary/classes/DomoAccount.py",
            ),
            "domolibrary.classes.DomoAccount.Account_Accesslist_Share._from_json": (
                "classes/domoaccount.html#account_accesslist_share._from_json",
                "domolibrary/classes/DomoAccount.py",
            ),
            "domolibrary.classes.DomoAccount.Account_Accesslist_Share._get_access_level": (
                "classes/domoaccount.html#account_accesslist_share._get_access_level",
                "domolibrary/classes/DomoAccount.py",
            ),
            "domolibrary.classes.DomoAccount.Account_Accesslist_Share._get_entity": (
                "classes/domoaccount.html#account_accesslist_share._get_entity",
                "domolibrary/classes/DomoAccount.py",
            ),
            "domolibrary.classes.DomoAccount.Account_CanIModify": (
                "classes/domoaccount.html#account_canimodify",
                "domolibrary/classes/DomoAccount.py",
            ),
            "domolibrary.classes.DomoAccount.Account_CanIModify.__init__": (
                "classes/domoaccount.html#account_canimodify.__init__",
                "domolibrary/classes/DomoAccount.py",
            ),
            "domolibrary.classes.DomoAccount.DomoAccounConfig_MissingFields": (
                "classes/domoaccount.html#domoaccounconfig_missingfields",
                "domolibrary/classes/DomoAccount.py",
            ),
            "domolibrary.classes.DomoAccount.DomoAccounConfig_MissingFields.__init__": (
                "classes/domoaccount.html#domoaccounconfig_missingfields.__init__",
                "domolibrary/classes/DomoAccount.py",
            ),
            "domolibrary.classes.DomoAccount.DomoAccount": (
                "classes/domoaccount.html#domoaccount",
                "domolibrary/classes/DomoAccount.py",
            ),
            "domolibrary.classes.DomoAccount.DomoAccount._from_json": (
                "classes/domoaccount.html#domoaccount._from_json",
                "domolibrary/classes/DomoAccount.py",
            ),
            "domolibrary.classes.DomoAccount.DomoAccount._get_config": (
                "classes/domoaccount.html#domoaccount._get_config",
                "domolibrary/classes/DomoAccount.py",
            ),
            "domolibrary.classes.DomoAccount.DomoAccount._share_v1": (
                "classes/domoaccount.html#domoaccount._share_v1",
                "domolibrary/classes/DomoAccount.py",
            ),
            "domolibrary.classes.DomoAccount.DomoAccount._share_v2": (
                "classes/domoaccount.html#domoaccount._share_v2",
                "domolibrary/classes/DomoAccount.py",
            ),
            "domolibrary.classes.DomoAccount.DomoAccount._test_missing_keys": (
                "classes/domoaccount.html#domoaccount._test_missing_keys",
                "domolibrary/classes/DomoAccount.py",
            ),
            "domolibrary.classes.DomoAccount.DomoAccount.create_account": (
                "classes/domoaccount.html#domoaccount.create_account",
                "domolibrary/classes/DomoAccount.py",
            ),
            "domolibrary.classes.DomoAccount.DomoAccount.delete_account": (
                "classes/domoaccount.html#domoaccount.delete_account",
                "domolibrary/classes/DomoAccount.py",
            ),
            "domolibrary.classes.DomoAccount.DomoAccount.get_accesslist": (
                "classes/domoaccount.html#domoaccount.get_accesslist",
                "domolibrary/classes/DomoAccount.py",
            ),
            "domolibrary.classes.DomoAccount.DomoAccount.get_by_id": (
                "classes/domoaccount.html#domoaccount.get_by_id",
                "domolibrary/classes/DomoAccount.py",
            ),
            "domolibrary.classes.DomoAccount.DomoAccount.is_feature_accountsv2_enabled": (
                "classes/domoaccount.html#domoaccount.is_feature_accountsv2_enabled",
                "domolibrary/classes/DomoAccount.py",
            ),
            "domolibrary.classes.DomoAccount.DomoAccount.share": (
                "classes/domoaccount.html#domoaccount.share",
                "domolibrary/classes/DomoAccount.py",
            ),
            "domolibrary.classes.DomoAccount.DomoAccount.update_config": (
                "classes/domoaccount.html#domoaccount.update_config",
                "domolibrary/classes/DomoAccount.py",
            ),
            "domolibrary.classes.DomoAccount.DomoAccount.update_name": (
                "classes/domoaccount.html#domoaccount.update_name",
                "domolibrary/classes/DomoAccount.py",
            ),
            "domolibrary.classes.DomoAccount.DomoAccount.upsert_share_account_group": (
                "classes/domoaccount.html#domoaccount.upsert_share_account_group",
                "domolibrary/classes/DomoAccount.py",
            ),
            "domolibrary.classes.DomoAccount.DomoAccount.upsert_share_account_user": (
                "classes/domoaccount.html#domoaccount.upsert_share_account_user",
                "domolibrary/classes/DomoAccount.py",
            ),
            "domolibrary.classes.DomoAccount.DomoAccounts": (
                "classes/domoaccount.html#domoaccounts",
                "domolibrary/classes/DomoAccount.py",
            ),
            "domolibrary.classes.DomoAccount.DomoAccounts._get_accounts_accountsapi": (
                "classes/domoaccount.html#domoaccounts._get_accounts_accountsapi",
                "domolibrary/classes/DomoAccount.py",
            ),
            "domolibrary.classes.DomoAccount.DomoAccounts._get_accounts_queryapi": (
                "classes/domoaccount.html#domoaccounts._get_accounts_queryapi",
                "domolibrary/classes/DomoAccount.py",
            ),
            "domolibrary.classes.DomoAccount.DomoAccounts.get_accounts": (
                "classes/domoaccount.html#domoaccounts.get_accounts",
                "domolibrary/classes/DomoAccount.py",
            ),
            "domolibrary.classes.DomoAccount.DomoAccounts.upsert_account": (
                "classes/domoaccount.html#domoaccounts.upsert_account",
                "domolibrary/classes/DomoAccount.py",
            ),
            "domolibrary.classes.DomoAccount.UpsertAccount_MatchCriteria": (
                "classes/domoaccount.html#upsertaccount_matchcriteria",
                "domolibrary/classes/DomoAccount.py",
            ),
            "domolibrary.classes.DomoAccount.UpsertAccount_MatchCriteria.__init__": (
                "classes/domoaccount.html#upsertaccount_matchcriteria.__init__",
                "domolibrary/classes/DomoAccount.py",
            ),
        },
        "domolibrary.classes.DomoAccount_Config": {
            "domolibrary.classes.DomoAccount_Config.AccountConfig": (
                "classes/domoaccount_config.html#accountconfig",
                "domolibrary/classes/DomoAccount_Config.py",
            ),
            "domolibrary.classes.DomoAccount_Config.AccountConfig._missing_": (
                "classes/domoaccount_config.html#accountconfig._missing_",
                "domolibrary/classes/DomoAccount_Config.py",
            ),
            "domolibrary.classes.DomoAccount_Config.AccountConfig._test_altname_search": (
                "classes/domoaccount_config.html#accountconfig._test_altname_search",
                "domolibrary/classes/DomoAccount_Config.py",
            ),
            "domolibrary.classes.DomoAccount_Config.AccountConfig_ProviderTypeNotDefined": (
                "classes/domoaccount_config.html#accountconfig_providertypenotdefined",
                "domolibrary/classes/DomoAccount_Config.py",
            ),
            "domolibrary.classes.DomoAccount_Config.AccountConfig_ProviderTypeNotDefined.__init__": (
                "classes/domoaccount_config.html#accountconfig_providertypenotdefined.__init__",
                "domolibrary/classes/DomoAccount_Config.py",
            ),
            "domolibrary.classes.DomoAccount_Config.AccountConfig_UsesOauth": (
                "classes/domoaccount_config.html#accountconfig_usesoauth",
                "domolibrary/classes/DomoAccount_Config.py",
            ),
            "domolibrary.classes.DomoAccount_Config.AccountConfig_UsesOauth.__init__": (
                "classes/domoaccount_config.html#accountconfig_usesoauth.__init__",
                "domolibrary/classes/DomoAccount_Config.py",
            ),
            "domolibrary.classes.DomoAccount_Config.DomoAccount_Config": (
                "classes/domoaccount_config.html#domoaccount_config",
                "domolibrary/classes/DomoAccount_Config.py",
            ),
            "domolibrary.classes.DomoAccount_Config.DomoAccount_Config._from_json": (
                "classes/domoaccount_config.html#domoaccount_config._from_json",
                "domolibrary/classes/DomoAccount_Config.py",
            ),
            "domolibrary.classes.DomoAccount_Config.DomoAccount_Config.to_json": (
                "classes/domoaccount_config.html#domoaccount_config.to_json",
                "domolibrary/classes/DomoAccount_Config.py",
            ),
            "domolibrary.classes.DomoAccount_Config.DomoAccount_Config_AbstractCredential": (
                "classes/domoaccount_config.html#domoaccount_config_abstractcredential",
                "domolibrary/classes/DomoAccount_Config.py",
            ),
            "domolibrary.classes.DomoAccount_Config.DomoAccount_Config_AbstractCredential._from_json": (
                "classes/domoaccount_config.html#domoaccount_config_abstractcredential._from_json",
                "domolibrary/classes/DomoAccount_Config.py",
            ),
            "domolibrary.classes.DomoAccount_Config.DomoAccount_Config_AbstractCredential.to_json": (
                "classes/domoaccount_config.html#domoaccount_config_abstractcredential.to_json",
                "domolibrary/classes/DomoAccount_Config.py",
            ),
            "domolibrary.classes.DomoAccount_Config.DomoAccount_Config_AmazonS3": (
                "classes/domoaccount_config.html#domoaccount_config_amazons3",
                "domolibrary/classes/DomoAccount_Config.py",
            ),
            "domolibrary.classes.DomoAccount_Config.DomoAccount_Config_AmazonS3._from_json": (
                "classes/domoaccount_config.html#domoaccount_config_amazons3._from_json",
                "domolibrary/classes/DomoAccount_Config.py",
            ),
            "domolibrary.classes.DomoAccount_Config.DomoAccount_Config_AmazonS3.to_json": (
                "classes/domoaccount_config.html#domoaccount_config_amazons3.to_json",
                "domolibrary/classes/DomoAccount_Config.py",
            ),
            "domolibrary.classes.DomoAccount_Config.DomoAccount_Config_AmazonS3Advanced": (
                "classes/domoaccount_config.html#domoaccount_config_amazons3advanced",
                "domolibrary/classes/DomoAccount_Config.py",
            ),
            "domolibrary.classes.DomoAccount_Config.DomoAccount_Config_AmazonS3Advanced._from_json": (
                "classes/domoaccount_config.html#domoaccount_config_amazons3advanced._from_json",
                "domolibrary/classes/DomoAccount_Config.py",
            ),
            "domolibrary.classes.DomoAccount_Config.DomoAccount_Config_AmazonS3Advanced.to_json": (
                "classes/domoaccount_config.html#domoaccount_config_amazons3advanced.to_json",
                "domolibrary/classes/DomoAccount_Config.py",
            ),
            "domolibrary.classes.DomoAccount_Config.DomoAccount_Config_AwsAthena": (
                "classes/domoaccount_config.html#domoaccount_config_awsathena",
                "domolibrary/classes/DomoAccount_Config.py",
            ),
            "domolibrary.classes.DomoAccount_Config.DomoAccount_Config_AwsAthena._from_json": (
                "classes/domoaccount_config.html#domoaccount_config_awsathena._from_json",
                "domolibrary/classes/DomoAccount_Config.py",
            ),
            "domolibrary.classes.DomoAccount_Config.DomoAccount_Config_AwsAthena.to_json": (
                "classes/domoaccount_config.html#domoaccount_config_awsathena.to_json",
                "domolibrary/classes/DomoAccount_Config.py",
            ),
            "domolibrary.classes.DomoAccount_Config.DomoAccount_Config_DatasetCopy": (
                "classes/domoaccount_config.html#domoaccount_config_datasetcopy",
                "domolibrary/classes/DomoAccount_Config.py",
            ),
            "domolibrary.classes.DomoAccount_Config.DomoAccount_Config_DatasetCopy._from_json": (
                "classes/domoaccount_config.html#domoaccount_config_datasetcopy._from_json",
                "domolibrary/classes/DomoAccount_Config.py",
            ),
            "domolibrary.classes.DomoAccount_Config.DomoAccount_Config_DatasetCopy.to_json": (
                "classes/domoaccount_config.html#domoaccount_config_datasetcopy.to_json",
                "domolibrary/classes/DomoAccount_Config.py",
            ),
            "domolibrary.classes.DomoAccount_Config.DomoAccount_Config_DomoAccessToken": (
                "classes/domoaccount_config.html#domoaccount_config_domoaccesstoken",
                "domolibrary/classes/DomoAccount_Config.py",
            ),
            "domolibrary.classes.DomoAccount_Config.DomoAccount_Config_DomoAccessToken._from_json": (
                "classes/domoaccount_config.html#domoaccount_config_domoaccesstoken._from_json",
                "domolibrary/classes/DomoAccount_Config.py",
            ),
            "domolibrary.classes.DomoAccount_Config.DomoAccount_Config_DomoAccessToken.to_json": (
                "classes/domoaccount_config.html#domoaccount_config_domoaccesstoken.to_json",
                "domolibrary/classes/DomoAccount_Config.py",
            ),
            "domolibrary.classes.DomoAccount_Config.DomoAccount_Config_Governance": (
                "classes/domoaccount_config.html#domoaccount_config_governance",
                "domolibrary/classes/DomoAccount_Config.py",
            ),
            "domolibrary.classes.DomoAccount_Config.DomoAccount_Config_Governance._from_json": (
                "classes/domoaccount_config.html#domoaccount_config_governance._from_json",
                "domolibrary/classes/DomoAccount_Config.py",
            ),
            "domolibrary.classes.DomoAccount_Config.DomoAccount_Config_Governance.to_json": (
                "classes/domoaccount_config.html#domoaccount_config_governance.to_json",
                "domolibrary/classes/DomoAccount_Config.py",
            ),
            "domolibrary.classes.DomoAccount_Config.DomoAccount_Config_HighBandwidthConnector": (
                "classes/domoaccount_config.html#domoaccount_config_highbandwidthconnector",
                "domolibrary/classes/DomoAccount_Config.py",
            ),
            "domolibrary.classes.DomoAccount_Config.DomoAccount_Config_HighBandwidthConnector._from_json": (
                "classes/domoaccount_config.html#domoaccount_config_highbandwidthconnector._from_json",
                "domolibrary/classes/DomoAccount_Config.py",
            ),
            "domolibrary.classes.DomoAccount_Config.DomoAccount_Config_HighBandwidthConnector.to_json": (
                "classes/domoaccount_config.html#domoaccount_config_highbandwidthconnector.to_json",
                "domolibrary/classes/DomoAccount_Config.py",
            ),
            "domolibrary.classes.DomoAccount_Config.DomoAccount_Config_Snowflake": (
                "classes/domoaccount_config.html#domoaccount_config_snowflake",
                "domolibrary/classes/DomoAccount_Config.py",
            ),
            "domolibrary.classes.DomoAccount_Config.DomoAccount_Config_Snowflake._from_json": (
                "classes/domoaccount_config.html#domoaccount_config_snowflake._from_json",
                "domolibrary/classes/DomoAccount_Config.py",
            ),
            "domolibrary.classes.DomoAccount_Config.DomoAccount_Config_Snowflake.to_json": (
                "classes/domoaccount_config.html#domoaccount_config_snowflake.to_json",
                "domolibrary/classes/DomoAccount_Config.py",
            ),
            "domolibrary.classes.DomoAccount_Config.DomoAccount_Config_SnowflakeFederated": (
                "classes/domoaccount_config.html#domoaccount_config_snowflakefederated",
                "domolibrary/classes/DomoAccount_Config.py",
            ),
            "domolibrary.classes.DomoAccount_Config.DomoAccount_Config_SnowflakeFederated._from_json": (
                "classes/domoaccount_config.html#domoaccount_config_snowflakefederated._from_json",
                "domolibrary/classes/DomoAccount_Config.py",
            ),
            "domolibrary.classes.DomoAccount_Config.DomoAccount_Config_SnowflakeFederated.to_json": (
                "classes/domoaccount_config.html#domoaccount_config_snowflakefederated.to_json",
                "domolibrary/classes/DomoAccount_Config.py",
            ),
            "domolibrary.classes.DomoAccount_Config.DomoAccount_Config_SnowflakeInternalUnload": (
                "classes/domoaccount_config.html#domoaccount_config_snowflakeinternalunload",
                "domolibrary/classes/DomoAccount_Config.py",
            ),
            "domolibrary.classes.DomoAccount_Config.DomoAccount_Config_SnowflakeInternalUnload._from_json": (
                "classes/domoaccount_config.html#domoaccount_config_snowflakeinternalunload._from_json",
                "domolibrary/classes/DomoAccount_Config.py",
            ),
            "domolibrary.classes.DomoAccount_Config.DomoAccount_Config_SnowflakeInternalUnload.to_json": (
                "classes/domoaccount_config.html#domoaccount_config_snowflakeinternalunload.to_json",
                "domolibrary/classes/DomoAccount_Config.py",
            ),
            "domolibrary.classes.DomoAccount_Config.DomoAccount_Config_SnowflakeKeyPairAuthentication": (
                "classes/domoaccount_config.html#domoaccount_config_snowflakekeypairauthentication",
                "domolibrary/classes/DomoAccount_Config.py",
            ),
            "domolibrary.classes.DomoAccount_Config.DomoAccount_Config_SnowflakeKeyPairAuthentication._from_json": (
                "classes/domoaccount_config.html#domoaccount_config_snowflakekeypairauthentication._from_json",
                "domolibrary/classes/DomoAccount_Config.py",
            ),
            "domolibrary.classes.DomoAccount_Config.DomoAccount_Config_SnowflakeKeyPairAuthentication.to_json": (
                "classes/domoaccount_config.html#domoaccount_config_snowflakekeypairauthentication.to_json",
                "domolibrary/classes/DomoAccount_Config.py",
            ),
            "domolibrary.classes.DomoAccount_Config.DomoAccount_Config_SnowflakeUnload": (
                "classes/domoaccount_config.html#domoaccount_config_snowflakeunload",
                "domolibrary/classes/DomoAccount_Config.py",
            ),
            "domolibrary.classes.DomoAccount_Config.DomoAccount_Config_SnowflakeUnload._from_json": (
                "classes/domoaccount_config.html#domoaccount_config_snowflakeunload._from_json",
                "domolibrary/classes/DomoAccount_Config.py",
            ),
            "domolibrary.classes.DomoAccount_Config.DomoAccount_Config_SnowflakeUnload.to_json": (
                "classes/domoaccount_config.html#domoaccount_config_snowflakeunload.to_json",
                "domolibrary/classes/DomoAccount_Config.py",
            ),
            "domolibrary.classes.DomoAccount_Config.DomoAccount_Config_SnowflakeUnloadAdvancedPartition": (
                "classes/domoaccount_config.html#domoaccount_config_snowflakeunloadadvancedpartition",
                "domolibrary/classes/DomoAccount_Config.py",
            ),
            "domolibrary.classes.DomoAccount_Config.DomoAccount_Config_SnowflakeUnloadAdvancedPartition._from_json": (
                "classes/domoaccount_config.html#domoaccount_config_snowflakeunloadadvancedpartition._from_json",
                "domolibrary/classes/DomoAccount_Config.py",
            ),
            "domolibrary.classes.DomoAccount_Config.DomoAccount_Config_SnowflakeUnloadAdvancedPartition.to_json": (
                "classes/domoaccount_config.html#domoaccount_config_snowflakeunloadadvancedpartition.to_json",
                "domolibrary/classes/DomoAccount_Config.py",
            ),
            "domolibrary.classes.DomoAccount_Config.DomoAccount_Config_SnowflakeUnload_V2": (
                "classes/domoaccount_config.html#domoaccount_config_snowflakeunload_v2",
                "domolibrary/classes/DomoAccount_Config.py",
            ),
            "domolibrary.classes.DomoAccount_Config.DomoAccount_Config_SnowflakeUnload_V2._from_json": (
                "classes/domoaccount_config.html#domoaccount_config_snowflakeunload_v2._from_json",
                "domolibrary/classes/DomoAccount_Config.py",
            ),
            "domolibrary.classes.DomoAccount_Config.DomoAccount_Config_SnowflakeUnload_V2.to_json": (
                "classes/domoaccount_config.html#domoaccount_config_snowflakeunload_v2.to_json",
                "domolibrary/classes/DomoAccount_Config.py",
            ),
            "domolibrary.classes.DomoAccount_Config.DomoAccount_Config_SnowflakeWriteback": (
                "classes/domoaccount_config.html#domoaccount_config_snowflakewriteback",
                "domolibrary/classes/DomoAccount_Config.py",
            ),
            "domolibrary.classes.DomoAccount_Config.DomoAccount_Config_SnowflakeWriteback._from_json": (
                "classes/domoaccount_config.html#domoaccount_config_snowflakewriteback._from_json",
                "domolibrary/classes/DomoAccount_Config.py",
            ),
            "domolibrary.classes.DomoAccount_Config.DomoAccount_Config_SnowflakeWriteback.to_json": (
                "classes/domoaccount_config.html#domoaccount_config_snowflakewriteback.to_json",
                "domolibrary/classes/DomoAccount_Config.py",
            ),
            "domolibrary.classes.DomoAccount_Config.DomoAccount_NoConfig": (
                "classes/domoaccount_config.html#domoaccount_noconfig",
                "domolibrary/classes/DomoAccount_Config.py",
            ),
            "domolibrary.classes.DomoAccount_Config.DomoAccount_NoConfig._from_json": (
                "classes/domoaccount_config.html#domoaccount_noconfig._from_json",
                "domolibrary/classes/DomoAccount_Config.py",
            ),
            "domolibrary.classes.DomoAccount_Config.DomoAccount_NoConfig.to_json": (
                "classes/domoaccount_config.html#domoaccount_noconfig.to_json",
                "domolibrary/classes/DomoAccount_Config.py",
            ),
            "domolibrary.classes.DomoAccount_Config.DomoAccount_NoConfig_OAuth": (
                "classes/domoaccount_config.html#domoaccount_noconfig_oauth",
                "domolibrary/classes/DomoAccount_Config.py",
            ),
            "domolibrary.classes.DomoAccount_Config.DomoAccount_NoConfig_OAuth._from_json": (
                "classes/domoaccount_config.html#domoaccount_noconfig_oauth._from_json",
                "domolibrary/classes/DomoAccount_Config.py",
            ),
            "domolibrary.classes.DomoAccount_Config.DomoAccount_NoConfig_OAuth.to_json": (
                "classes/domoaccount_config.html#domoaccount_noconfig_oauth.to_json",
                "domolibrary/classes/DomoAccount_Config.py",
            ),
        },
        "domolibrary.classes.DomoActivityLog": {
            "domolibrary.classes.DomoActivityLog.ActivityLog_ObjectType": (
                "classes/domoactivitylog.html#activitylog_objecttype",
                "domolibrary/classes/DomoActivityLog.py",
            ),
            "domolibrary.classes.DomoActivityLog.DomoActivityLog": (
                "classes/domoactivitylog.html#domoactivitylog",
                "domolibrary/classes/DomoActivityLog.py",
            ),
            "domolibrary.classes.DomoActivityLog.DomoActivityLog._process_activity_log_row": (
                "classes/domoactivitylog.html#domoactivitylog._process_activity_log_row",
                "domolibrary/classes/DomoActivityLog.py",
            ),
            "domolibrary.classes.DomoActivityLog.DomoActivityLog.get_activity_log": (
                "classes/domoactivitylog.html#domoactivitylog.get_activity_log",
                "domolibrary/classes/DomoActivityLog.py",
            ),
        },
        "domolibrary.classes.DomoApplication": {
            "domolibrary.classes.DomoApplication.DomoApplication": (
                "classes/domoapplication.html#domoapplication",
                "domolibrary/classes/DomoApplication.py",
            ),
            "domolibrary.classes.DomoApplication.DomoApplication._from_json": (
                "classes/domoapplication.html#domoapplication._from_json",
                "domolibrary/classes/DomoApplication.py",
            ),
            "domolibrary.classes.DomoApplication.DomoApplication._get_job_class": (
                "classes/domoapplication.html#domoapplication._get_job_class",
                "domolibrary/classes/DomoApplication.py",
            ),
            "domolibrary.classes.DomoApplication.DomoApplication.find_next_job_schedule": (
                "classes/domoapplication.html#domoapplication.find_next_job_schedule",
                "domolibrary/classes/DomoApplication.py",
            ),
            "domolibrary.classes.DomoApplication.DomoApplication.get_from_id": (
                "classes/domoapplication.html#domoapplication.get_from_id",
                "domolibrary/classes/DomoApplication.py",
            ),
        },
        "domolibrary.classes.DomoApplication_Job": {
            "domolibrary.classes.DomoApplication_Job.DomoJob": (
                "classes/domoapplication_job.html#domojob",
                "domolibrary/classes/DomoApplication_Job.py",
            ),
            "domolibrary.classes.DomoApplication_Job.DomoJob._convert_API_res_to_DomoJob_base_obj": (
                "classes/domoapplication_job.html#domojob._convert_api_res_to_domojob_base_obj",
                "domolibrary/classes/DomoApplication_Job.py",
            ),
            "domolibrary.classes.DomoApplication_Job.DomoJob._format_remote_instance": (
                "classes/domoapplication_job.html#domojob._format_remote_instance",
                "domolibrary/classes/DomoApplication_Job.py",
            ),
            "domolibrary.classes.DomoApplication_Job.DomoJob._from_json": (
                "classes/domoapplication_job.html#domojob._from_json",
                "domolibrary/classes/DomoApplication_Job.py",
            ),
            "domolibrary.classes.DomoApplication_Job.DomoJob._generate_to_json": (
                "classes/domoapplication_job.html#domojob._generate_to_json",
                "domolibrary/classes/DomoApplication_Job.py",
            ),
            "domolibrary.classes.DomoApplication_Job.DomoJob._get_by_id": (
                "classes/domoapplication_job.html#domojob._get_by_id",
                "domolibrary/classes/DomoApplication_Job.py",
            ),
            "domolibrary.classes.DomoApplication_Job.DomoJob.execute": (
                "classes/domoapplication_job.html#domojob.execute",
                "domolibrary/classes/DomoApplication_Job.py",
            ),
            "domolibrary.classes.DomoApplication_Job.DomoJob.get_by_id": (
                "classes/domoapplication_job.html#domojob.get_by_id",
                "domolibrary/classes/DomoApplication_Job.py",
            ),
            "domolibrary.classes.DomoApplication_Job.DomoJob.to_json": (
                "classes/domoapplication_job.html#domojob.to_json",
                "domolibrary/classes/DomoApplication_Job.py",
            ),
            "domolibrary.classes.DomoApplication_Job.DomoJob.update": (
                "classes/domoapplication_job.html#domojob.update",
                "domolibrary/classes/DomoApplication_Job.py",
            ),
            "domolibrary.classes.DomoApplication_Job.DomoJob_RemoteDomoStats": (
                "classes/domoapplication_job.html#domojob_remotedomostats",
                "domolibrary/classes/DomoApplication_Job.py",
            ),
            "domolibrary.classes.DomoApplication_Job.DomoJob_RemoteDomoStats._from_json": (
                "classes/domoapplication_job.html#domojob_remotedomostats._from_json",
                "domolibrary/classes/DomoApplication_Job.py",
            ),
            "domolibrary.classes.DomoApplication_Job.DomoJob_RemoteDomoStats.create": (
                "classes/domoapplication_job.html#domojob_remotedomostats.create",
                "domolibrary/classes/DomoApplication_Job.py",
            ),
            "domolibrary.classes.DomoApplication_Job.DomoJob_RemoteDomoStats.get_by_id": (
                "classes/domoapplication_job.html#domojob_remotedomostats.get_by_id",
                "domolibrary/classes/DomoApplication_Job.py",
            ),
            "domolibrary.classes.DomoApplication_Job.DomoJob_RemoteDomoStats.to_json": (
                "classes/domoapplication_job.html#domojob_remotedomostats.to_json",
                "domolibrary/classes/DomoApplication_Job.py",
            ),
            "domolibrary.classes.DomoApplication_Job.DomoJob_Watchdog": (
                "classes/domoapplication_job.html#domojob_watchdog",
                "domolibrary/classes/DomoApplication_Job.py",
            ),
            "domolibrary.classes.DomoApplication_Job.DomoJob_Watchdog._from_json": (
                "classes/domoapplication_job.html#domojob_watchdog._from_json",
                "domolibrary/classes/DomoApplication_Job.py",
            ),
            "domolibrary.classes.DomoApplication_Job.DomoJob_Watchdog.create": (
                "classes/domoapplication_job.html#domojob_watchdog.create",
                "domolibrary/classes/DomoApplication_Job.py",
            ),
            "domolibrary.classes.DomoApplication_Job.DomoJob_Watchdog.get_by_id": (
                "classes/domoapplication_job.html#domojob_watchdog.get_by_id",
                "domolibrary/classes/DomoApplication_Job.py",
            ),
            "domolibrary.classes.DomoApplication_Job.DomoJob_Watchdog.to_json": (
                "classes/domoapplication_job.html#domojob_watchdog.to_json",
                "domolibrary/classes/DomoApplication_Job.py",
            ),
            "domolibrary.classes.DomoApplication_Job.DomoTrigger": (
                "classes/domoapplication_job.html#domotrigger",
                "domolibrary/classes/DomoApplication_Job.py",
            ),
            "domolibrary.classes.DomoApplication_Job.DomoTrigger._from_json": (
                "classes/domoapplication_job.html#domotrigger._from_json",
                "domolibrary/classes/DomoApplication_Job.py",
            ),
            "domolibrary.classes.DomoApplication_Job.DomoTrigger_Schedule": (
                "classes/domoapplication_job.html#domotrigger_schedule",
                "domolibrary/classes/DomoApplication_Job.py",
            ),
            "domolibrary.classes.DomoApplication_Job.DomoTrigger_Schedule._from_str": (
                "classes/domoapplication_job.html#domotrigger_schedule._from_str",
                "domolibrary/classes/DomoApplication_Job.py",
            ),
            "domolibrary.classes.DomoApplication_Job.DomoTrigger_Schedule.to_json": (
                "classes/domoapplication_job.html#domotrigger_schedule.to_json",
                "domolibrary/classes/DomoApplication_Job.py",
            ),
            "domolibrary.classes.DomoApplication_Job.DomoTrigger_Schedule.to_obj": (
                "classes/domoapplication_job.html#domotrigger_schedule.to_obj",
                "domolibrary/classes/DomoApplication_Job.py",
            ),
            "domolibrary.classes.DomoApplication_Job.RemoteDomoStats_Config": (
                "classes/domoapplication_job.html#remotedomostats_config",
                "domolibrary/classes/DomoApplication_Job.py",
            ),
            "domolibrary.classes.DomoApplication_Job.RemoteDomoStats_Config._add_policy": (
                "classes/domoapplication_job.html#remotedomostats_config._add_policy",
                "domolibrary/classes/DomoApplication_Job.py",
            ),
            "domolibrary.classes.DomoApplication_Job.RemoteDomoStats_Config._from_json": (
                "classes/domoapplication_job.html#remotedomostats_config._from_json",
                "domolibrary/classes/DomoApplication_Job.py",
            ),
            "domolibrary.classes.DomoApplication_Job.RemoteDomoStats_Config.to_json": (
                "classes/domoapplication_job.html#remotedomostats_config.to_json",
                "domolibrary/classes/DomoApplication_Job.py",
            ),
            "domolibrary.classes.DomoApplication_Job.RemoteDomoStats_Config_Policy": (
                "classes/domoapplication_job.html#remotedomostats_config_policy",
                "domolibrary/classes/DomoApplication_Job.py",
            ),
            "domolibrary.classes.DomoApplication_Job.RemoteDomoStats_Config_Policy.__eq__": (
                "classes/domoapplication_job.html#remotedomostats_config_policy.__eq__",
                "domolibrary/classes/DomoApplication_Job.py",
            ),
            "domolibrary.classes.DomoApplication_Job.RemoteDomoStats_Config_Policy.to_json": (
                "classes/domoapplication_job.html#remotedomostats_config_policy.to_json",
                "domolibrary/classes/DomoApplication_Job.py",
            ),
            "domolibrary.classes.DomoApplication_Job.Watchdog_Config": (
                "classes/domoapplication_job.html#watchdog_config",
                "domolibrary/classes/DomoApplication_Job.py",
            ),
            "domolibrary.classes.DomoApplication_Job.Watchdog_Config._from_json": (
                "classes/domoapplication_job.html#watchdog_config._from_json",
                "domolibrary/classes/DomoApplication_Job.py",
            ),
            "domolibrary.classes.DomoApplication_Job.Watchdog_Config._to_json": (
                "classes/domoapplication_job.html#watchdog_config._to_json",
                "domolibrary/classes/DomoApplication_Job.py",
            ),
            "domolibrary.classes.DomoApplication_Job.Watchdog_Config.to_json": (
                "classes/domoapplication_job.html#watchdog_config.to_json",
                "domolibrary/classes/DomoApplication_Job.py",
            ),
            "domolibrary.classes.DomoApplication_Job.Watchdog_ConfigFactory": (
                "classes/domoapplication_job.html#watchdog_configfactory",
                "domolibrary/classes/DomoApplication_Job.py",
            ),
            "domolibrary.classes.DomoApplication_Job.Watchdog_Config_CustomQuery": (
                "classes/domoapplication_job.html#watchdog_config_customquery",
                "domolibrary/classes/DomoApplication_Job.py",
            ),
            "domolibrary.classes.DomoApplication_Job.Watchdog_Config_CustomQuery.__post_init__": (
                "classes/domoapplication_job.html#watchdog_config_customquery.__post_init__",
                "domolibrary/classes/DomoApplication_Job.py",
            ),
            "domolibrary.classes.DomoApplication_Job.Watchdog_Config_CustomQuery.to_json": (
                "classes/domoapplication_job.html#watchdog_config_customquery.to_json",
                "domolibrary/classes/DomoApplication_Job.py",
            ),
            "domolibrary.classes.DomoApplication_Job.Watchdog_Config_ErrorDetection": (
                "classes/domoapplication_job.html#watchdog_config_errordetection",
                "domolibrary/classes/DomoApplication_Job.py",
            ),
            "domolibrary.classes.DomoApplication_Job.Watchdog_Config_ErrorDetection.to_json": (
                "classes/domoapplication_job.html#watchdog_config_errordetection.to_json",
                "domolibrary/classes/DomoApplication_Job.py",
            ),
            "domolibrary.classes.DomoApplication_Job.Watchdog_Config_ExecutionVariance": (
                "classes/domoapplication_job.html#watchdog_config_executionvariance",
                "domolibrary/classes/DomoApplication_Job.py",
            ),
            "domolibrary.classes.DomoApplication_Job.Watchdog_Config_LastDataUpdated": (
                "classes/domoapplication_job.html#watchdog_config_lastdataupdated",
                "domolibrary/classes/DomoApplication_Job.py",
            ),
            "domolibrary.classes.DomoApplication_Job.Watchdog_Config_LastDataUpdated.__post_init__": (
                "classes/domoapplication_job.html#watchdog_config_lastdataupdated.__post_init__",
                "domolibrary/classes/DomoApplication_Job.py",
            ),
            "domolibrary.classes.DomoApplication_Job.Watchdog_Config_LastDataUpdated.to_json": (
                "classes/domoapplication_job.html#watchdog_config_lastdataupdated.to_json",
                "domolibrary/classes/DomoApplication_Job.py",
            ),
            "domolibrary.classes.DomoApplication_Job.Watchdog_Config_MaxIndexingTime": (
                "classes/domoapplication_job.html#watchdog_config_maxindexingtime",
                "domolibrary/classes/DomoApplication_Job.py",
            ),
            "domolibrary.classes.DomoApplication_Job.Watchdog_Config_MaxIndexingTime.__post_init__": (
                "classes/domoapplication_job.html#watchdog_config_maxindexingtime.__post_init__",
                "domolibrary/classes/DomoApplication_Job.py",
            ),
            "domolibrary.classes.DomoApplication_Job.Watchdog_Config_MaxIndexingTime.to_json": (
                "classes/domoapplication_job.html#watchdog_config_maxindexingtime.to_json",
                "domolibrary/classes/DomoApplication_Job.py",
            ),
            "domolibrary.classes.DomoApplication_Job.Watchdog_Config_RowCountVariance": (
                "classes/domoapplication_job.html#watchdog_config_rowcountvariance",
                "domolibrary/classes/DomoApplication_Job.py",
            ),
            "domolibrary.classes.DomoApplication_Job.Watchdog_Config__Variance": (
                "classes/domoapplication_job.html#watchdog_config__variance",
                "domolibrary/classes/DomoApplication_Job.py",
            ),
            "domolibrary.classes.DomoApplication_Job.Watchdog_Config__Variance.__post_init__": (
                "classes/domoapplication_job.html#watchdog_config__variance.__post_init__",
                "domolibrary/classes/DomoApplication_Job.py",
            ),
            "domolibrary.classes.DomoApplication_Job.Watchdog_Config__Variance.to_json": (
                "classes/domoapplication_job.html#watchdog_config__variance.to_json",
                "domolibrary/classes/DomoApplication_Job.py",
            ),
        },
        "domolibrary.classes.DomoBootstrap": {
            "domolibrary.classes.DomoBootstrap.DomoBootstrap": (
                "classes/domobootstrap.html#domobootstrap",
                "domolibrary/classes/DomoBootstrap.py",
            ),
            "domolibrary.classes.DomoBootstrap.DomoBootstrap.get_all": (
                "classes/domobootstrap.html#domobootstrap.get_all",
                "domolibrary/classes/DomoBootstrap.py",
            ),
            "domolibrary.classes.DomoBootstrap.DomoBootstrap.get_customer_id": (
                "classes/domobootstrap.html#domobootstrap.get_customer_id",
                "domolibrary/classes/DomoBootstrap.py",
            ),
            "domolibrary.classes.DomoBootstrap.DomoBootstrap.get_features": (
                "classes/domobootstrap.html#domobootstrap.get_features",
                "domolibrary/classes/DomoBootstrap.py",
            ),
            "domolibrary.classes.DomoBootstrap.DomoBootstrap.get_pages": (
                "classes/domobootstrap.html#domobootstrap.get_pages",
                "domolibrary/classes/DomoBootstrap.py",
            ),
            "domolibrary.classes.DomoBootstrap.DomoBootstrap.is_feature_accountsv2_enabled": (
                "classes/domobootstrap.html#domobootstrap.is_feature_accountsv2_enabled",
                "domolibrary/classes/DomoBootstrap.py",
            ),
            "domolibrary.classes.DomoBootstrap.DomoBootstrap_Feature": (
                "classes/domobootstrap.html#domobootstrap_feature",
                "domolibrary/classes/DomoBootstrap.py",
            ),
            "domolibrary.classes.DomoBootstrap.DomoBootstrap_Feature._from_json_bootstrap": (
                "classes/domobootstrap.html#domobootstrap_feature._from_json_bootstrap",
                "domolibrary/classes/DomoBootstrap.py",
            ),
        },
        "domolibrary.classes.DomoCard": {
            "domolibrary.classes.DomoCard.DomoCard": (
                "classes/domocard.html#domocard",
                "domolibrary/classes/DomoCard.py",
            ),
            "domolibrary.classes.DomoCard.DomoCard.__post_init__": (
                "classes/domocard.html#domocard.__post_init__",
                "domolibrary/classes/DomoCard.py",
            ),
            "domolibrary.classes.DomoCard.DomoCard._from_json": (
                "classes/domocard.html#domocard._from_json",
                "domolibrary/classes/DomoCard.py",
            ),
            "domolibrary.classes.DomoCard.DomoCard.display_url": (
                "classes/domocard.html#domocard.display_url",
                "domolibrary/classes/DomoCard.py",
            ),
            "domolibrary.classes.DomoCard.DomoCard.get_by_id": (
                "classes/domocard.html#domocard.get_by_id",
                "domolibrary/classes/DomoCard.py",
            ),
            "domolibrary.classes.DomoCard.DomoCard.share": (
                "classes/domocard.html#domocard.share",
                "domolibrary/classes/DomoCard.py",
            ),
        },
        "domolibrary.classes.DomoCertification": {
            "domolibrary.classes.DomoCertification.DomoCertification": (
                "classes/domocertification.html#domocertification",
                "domolibrary/classes/DomoCertification.py",
            ),
            "domolibrary.classes.DomoCertification.DomoCertification._from_json": (
                "classes/domocertification.html#domocertification._from_json",
                "domolibrary/classes/DomoCertification.py",
            ),
            "domolibrary.classes.DomoCertification.DomoCertificationState": (
                "classes/domocertification.html#domocertificationstate",
                "domolibrary/classes/DomoCertification.py",
            ),
        },
        "domolibrary.classes.DomoDatacenter": {
            "domolibrary.classes.DomoDatacenter.DomoDatacenter": (
                "classes/domodatacenter.html#domodatacenter",
                "domolibrary/classes/DomoDatacenter.py",
            ),
            "domolibrary.classes.DomoDatacenter.DomoDatacenter.get_accounts": (
                "classes/domodatacenter.html#domodatacenter.get_accounts",
                "domolibrary/classes/DomoDatacenter.py",
            ),
            "domolibrary.classes.DomoDatacenter.DomoDatacenter.get_cards_admin_summary": (
                "classes/domodatacenter.html#domodatacenter.get_cards_admin_summary",
                "domolibrary/classes/DomoDatacenter.py",
            ),
            "domolibrary.classes.DomoDatacenter.DomoDatacenter.get_lineage_upstream": (
                "classes/domodatacenter.html#domodatacenter.get_lineage_upstream",
                "domolibrary/classes/DomoDatacenter.py",
            ),
            "domolibrary.classes.DomoDatacenter.DomoDatacenter.search_cards": (
                "classes/domodatacenter.html#domodatacenter.search_cards",
                "domolibrary/classes/DomoDatacenter.py",
            ),
            "domolibrary.classes.DomoDatacenter.DomoDatacenter.search_datacenter": (
                "classes/domodatacenter.html#domodatacenter.search_datacenter",
                "domolibrary/classes/DomoDatacenter.py",
            ),
            "domolibrary.classes.DomoDatacenter.DomoDatacenter.search_datasets": (
                "classes/domodatacenter.html#domodatacenter.search_datasets",
                "domolibrary/classes/DomoDatacenter.py",
            ),
            "domolibrary.classes.DomoDatacenter.LineageTypes_Enum": (
                "classes/domodatacenter.html#lineagetypes_enum",
                "domolibrary/classes/DomoDatacenter.py",
            ),
        },
        "domolibrary.classes.DomoDataflow": {
            "domolibrary.classes.DomoDataflow.DomoDataflow": (
                "classes/domodataflow.html#domodataflow",
                "domolibrary/classes/DomoDataflow.py",
            ),
            "domolibrary.classes.DomoDataflow.DomoDataflow.__post_init__": (
                "classes/domodataflow.html#domodataflow.__post_init__",
                "domolibrary/classes/DomoDataflow.py",
            ),
            "domolibrary.classes.DomoDataflow.DomoDataflow._from_json": (
                "classes/domodataflow.html#domodataflow._from_json",
                "domolibrary/classes/DomoDataflow.py",
            ),
            "domolibrary.classes.DomoDataflow.DomoDataflow.execute": (
                "classes/domodataflow.html#domodataflow.execute",
                "domolibrary/classes/DomoDataflow.py",
            ),
            "domolibrary.classes.DomoDataflow.DomoDataflow.get_by_version_id": (
                "classes/domodataflow.html#domodataflow.get_by_version_id",
                "domolibrary/classes/DomoDataflow.py",
            ),
            "domolibrary.classes.DomoDataflow.DomoDataflow.get_from_id": (
                "classes/domodataflow.html#domodataflow.get_from_id",
                "domolibrary/classes/DomoDataflow.py",
            ),
            "domolibrary.classes.DomoDataflow.DomoDataflow.get_versions": (
                "classes/domodataflow.html#domodataflow.get_versions",
                "domolibrary/classes/DomoDataflow.py",
            ),
        },
        "domolibrary.classes.DomoDataflow_Action": {
            "domolibrary.classes.DomoDataflow_Action.DomoAction": (
                "classes/domodataflow_action.html#domoaction",
                "domolibrary/classes/DomoDataflow_Action.py",
            ),
            "domolibrary.classes.DomoDataflow_Action.DomoDataflow_Action": (
                "classes/domodataflow_action.html#domodataflow_action",
                "domolibrary/classes/DomoDataflow_Action.py",
            ),
            "domolibrary.classes.DomoDataflow_Action.DomoDataflow_Action._from_json": (
                "classes/domodataflow_action.html#domodataflow_action._from_json",
                "domolibrary/classes/DomoDataflow_Action.py",
            ),
            "domolibrary.classes.DomoDataflow_Action.DomoDataflow_Action.get_parents": (
                "classes/domodataflow_action.html#domodataflow_action.get_parents",
                "domolibrary/classes/DomoDataflow_Action.py",
            ),
            "domolibrary.classes.DomoDataflow_Action.DomoDataflow_ActionResult": (
                "classes/domodataflow_action.html#domodataflow_actionresult",
                "domolibrary/classes/DomoDataflow_Action.py",
            ),
            "domolibrary.classes.DomoDataflow_Action.DomoDataflow_ActionResult.__post_init__": (
                "classes/domodataflow_action.html#domodataflow_actionresult.__post_init__",
                "domolibrary/classes/DomoDataflow_Action.py",
            ),
            "domolibrary.classes.DomoDataflow_Action.DomoDataflow_ActionResult._from_json": (
                "classes/domodataflow_action.html#domodataflow_actionresult._from_json",
                "domolibrary/classes/DomoDataflow_Action.py",
            ),
            "domolibrary.classes.DomoDataflow_Action.DomoDataflow_Action_Type": (
                "classes/domodataflow_action.html#domodataflow_action_type",
                "domolibrary/classes/DomoDataflow_Action.py",
            ),
        },
        "domolibrary.classes.DomoDataflow_History": {
            "domolibrary.classes.DomoDataflow_History.DomoDataflow_History": (
                "classes/domodataflow_history.html#domodataflow_history",
                "domolibrary/classes/DomoDataflow_History.py",
            ),
            "domolibrary.classes.DomoDataflow_History.DomoDataflow_History.get_execution_history": (
                "classes/domodataflow_history.html#domodataflow_history.get_execution_history",
                "domolibrary/classes/DomoDataflow_History.py",
            ),
            "domolibrary.classes.DomoDataflow_History.DomoDataflow_History_Execution": (
                "classes/domodataflow_history.html#domodataflow_history_execution",
                "domolibrary/classes/DomoDataflow_History.py",
            ),
            "domolibrary.classes.DomoDataflow_History.DomoDataflow_History_Execution._from_json": (
                "classes/domodataflow_history.html#domodataflow_history_execution._from_json",
                "domolibrary/classes/DomoDataflow_History.py",
            ),
            "domolibrary.classes.DomoDataflow_History.DomoDataflow_History_Execution.get_actions": (
                "classes/domodataflow_history.html#domodataflow_history_execution.get_actions",
                "domolibrary/classes/DomoDataflow_History.py",
            ),
            "domolibrary.classes.DomoDataflow_History.DomoDataflow_History_Execution.get_by_id": (
                "classes/domodataflow_history.html#domodataflow_history_execution.get_by_id",
                "domolibrary/classes/DomoDataflow_History.py",
            ),
        },
        "domolibrary.classes.DomoDataset": {
            "domolibrary.classes.DomoDataset.DatasetSchema_InvalidSchema": (
                "classes/domodataset.html#datasetschema_invalidschema",
                "domolibrary/classes/DomoDataset.py",
            ),
            "domolibrary.classes.DomoDataset.DatasetSchema_InvalidSchema.__init__": (
                "classes/domodataset.html#datasetschema_invalidschema.__init__",
                "domolibrary/classes/DomoDataset.py",
            ),
            "domolibrary.classes.DomoDataset.DatasetSchema_Types": (
                "classes/domodataset.html#datasetschema_types",
                "domolibrary/classes/DomoDataset.py",
            ),
            "domolibrary.classes.DomoDataset.DatasetTags_SetTagsError": (
                "classes/domodataset.html#datasettags_settagserror",
                "domolibrary/classes/DomoDataset.py",
            ),
            "domolibrary.classes.DomoDataset.DatasetTags_SetTagsError.__init__": (
                "classes/domodataset.html#datasettags_settagserror.__init__",
                "domolibrary/classes/DomoDataset.py",
            ),
            "domolibrary.classes.DomoDataset.DomoDataset": (
                "classes/domodataset.html#domodataset",
                "domolibrary/classes/DomoDataset.py",
            ),
            "domolibrary.classes.DomoDataset.DomoDataset.__post_init__": (
                "classes/domodataset.html#domodataset.__post_init__",
                "domolibrary/classes/DomoDataset.py",
            ),
            "domolibrary.classes.DomoDataset.DomoDataset.create": (
                "classes/domodataset.html#domodataset.create",
                "domolibrary/classes/DomoDataset.py",
            ),
            "domolibrary.classes.DomoDataset.DomoDataset.delete": (
                "classes/domodataset.html#domodataset.delete",
                "domolibrary/classes/DomoDataset.py",
            ),
            "domolibrary.classes.DomoDataset.DomoDataset.delete_partition": (
                "classes/domodataset.html#domodataset.delete_partition",
                "domolibrary/classes/DomoDataset.py",
            ),
            "domolibrary.classes.DomoDataset.DomoDataset.display_url": (
                "classes/domodataset.html#domodataset.display_url",
                "domolibrary/classes/DomoDataset.py",
            ),
            "domolibrary.classes.DomoDataset.DomoDataset.get_from_id": (
                "classes/domodataset.html#domodataset.get_from_id",
                "domolibrary/classes/DomoDataset.py",
            ),
            "domolibrary.classes.DomoDataset.DomoDataset.index_dataset": (
                "classes/domodataset.html#domodataset.index_dataset",
                "domolibrary/classes/DomoDataset.py",
            ),
            "domolibrary.classes.DomoDataset.DomoDataset.list_partitions": (
                "classes/domodataset.html#domodataset.list_partitions",
                "domolibrary/classes/DomoDataset.py",
            ),
            "domolibrary.classes.DomoDataset.DomoDataset.query_dataset_private": (
                "classes/domodataset.html#domodataset.query_dataset_private",
                "domolibrary/classes/DomoDataset.py",
            ),
            "domolibrary.classes.DomoDataset.DomoDataset.reset_dataset": (
                "classes/domodataset.html#domodataset.reset_dataset",
                "domolibrary/classes/DomoDataset.py",
            ),
            "domolibrary.classes.DomoDataset.DomoDataset.share": (
                "classes/domodataset.html#domodataset.share",
                "domolibrary/classes/DomoDataset.py",
            ),
            "domolibrary.classes.DomoDataset.DomoDataset.upload_data": (
                "classes/domodataset.html#domodataset.upload_data",
                "domolibrary/classes/DomoDataset.py",
            ),
            "domolibrary.classes.DomoDataset.DomoDataset_CreateDataset_Error": (
                "classes/domodataset.html#domodataset_createdataset_error",
                "domolibrary/classes/DomoDataset.py",
            ),
            "domolibrary.classes.DomoDataset.DomoDataset_CreateDataset_Error.__init__": (
                "classes/domodataset.html#domodataset_createdataset_error.__init__",
                "domolibrary/classes/DomoDataset.py",
            ),
            "domolibrary.classes.DomoDataset.DomoDataset_DeleteDataset_Error": (
                "classes/domodataset.html#domodataset_deletedataset_error",
                "domolibrary/classes/DomoDataset.py",
            ),
            "domolibrary.classes.DomoDataset.DomoDataset_DeleteDataset_Error.__init__": (
                "classes/domodataset.html#domodataset_deletedataset_error.__init__",
                "domolibrary/classes/DomoDataset.py",
            ),
            "domolibrary.classes.DomoDataset.DomoDataset_Schema": (
                "classes/domodataset.html#domodataset_schema",
                "domolibrary/classes/DomoDataset.py",
            ),
            "domolibrary.classes.DomoDataset.DomoDataset_Schema._test_missing_columns": (
                "classes/domodataset.html#domodataset_schema._test_missing_columns",
                "domolibrary/classes/DomoDataset.py",
            ),
            "domolibrary.classes.DomoDataset.DomoDataset_Schema.add_col": (
                "classes/domodataset.html#domodataset_schema.add_col",
                "domolibrary/classes/DomoDataset.py",
            ),
            "domolibrary.classes.DomoDataset.DomoDataset_Schema.alter_schema": (
                "classes/domodataset.html#domodataset_schema.alter_schema",
                "domolibrary/classes/DomoDataset.py",
            ),
            "domolibrary.classes.DomoDataset.DomoDataset_Schema.get": (
                "classes/domodataset.html#domodataset_schema.get",
                "domolibrary/classes/DomoDataset.py",
            ),
            "domolibrary.classes.DomoDataset.DomoDataset_Schema.remove_col": (
                "classes/domodataset.html#domodataset_schema.remove_col",
                "domolibrary/classes/DomoDataset.py",
            ),
            "domolibrary.classes.DomoDataset.DomoDataset_Schema.reset_col_order": (
                "classes/domodataset.html#domodataset_schema.reset_col_order",
                "domolibrary/classes/DomoDataset.py",
            ),
            "domolibrary.classes.DomoDataset.DomoDataset_Schema.to_dict": (
                "classes/domodataset.html#domodataset_schema.to_dict",
                "domolibrary/classes/DomoDataset.py",
            ),
            "domolibrary.classes.DomoDataset.DomoDataset_Schema_Column": (
                "classes/domodataset.html#domodataset_schema_column",
                "domolibrary/classes/DomoDataset.py",
            ),
            "domolibrary.classes.DomoDataset.DomoDataset_Schema_Column.__eq__": (
                "classes/domodataset.html#domodataset_schema_column.__eq__",
                "domolibrary/classes/DomoDataset.py",
            ),
            "domolibrary.classes.DomoDataset.DomoDataset_Schema_Column._from_json": (
                "classes/domodataset.html#domodataset_schema_column._from_json",
                "domolibrary/classes/DomoDataset.py",
            ),
            "domolibrary.classes.DomoDataset.DomoDataset_Schema_Column.to_dict": (
                "classes/domodataset.html#domodataset_schema_column.to_dict",
                "domolibrary/classes/DomoDataset.py",
            ),
            "domolibrary.classes.DomoDataset.DomoDataset_Tags": (
                "classes/domodataset.html#domodataset_tags",
                "domolibrary/classes/DomoDataset.py",
            ),
            "domolibrary.classes.DomoDataset.DomoDataset_Tags.add": (
                "classes/domodataset.html#domodataset_tags.add",
                "domolibrary/classes/DomoDataset.py",
            ),
            "domolibrary.classes.DomoDataset.DomoDataset_Tags.get": (
                "classes/domodataset.html#domodataset_tags.get",
                "domolibrary/classes/DomoDataset.py",
            ),
            "domolibrary.classes.DomoDataset.DomoDataset_Tags.remove": (
                "classes/domodataset.html#domodataset_tags.remove",
                "domolibrary/classes/DomoDataset.py",
            ),
            "domolibrary.classes.DomoDataset.DomoDataset_Tags.set": (
                "classes/domodataset.html#domodataset_tags.set",
                "domolibrary/classes/DomoDataset.py",
            ),
            "domolibrary.classes.DomoDataset.QueryExecutionError": (
                "classes/domodataset.html#queryexecutionerror",
                "domolibrary/classes/DomoDataset.py",
            ),
            "domolibrary.classes.DomoDataset.QueryExecutionError.__init__": (
                "classes/domodataset.html#queryexecutionerror.__init__",
                "domolibrary/classes/DomoDataset.py",
            ),
            "domolibrary.classes.DomoDataset._have_prereqs": (
                "classes/domodataset.html#_have_prereqs",
                "domolibrary/classes/DomoDataset.py",
            ),
        },
        "domolibrary.classes.DomoGrant": {
            "domolibrary.classes.DomoGrant.DomoGrant": (
                "classes/domogrant.html#domogrant",
                "domolibrary/classes/DomoGrant.py",
            ),
            "domolibrary.classes.DomoGrant.DomoGrant.__eq__": (
                "classes/domogrant.html#domogrant.__eq__",
                "domolibrary/classes/DomoGrant.py",
            ),
            "domolibrary.classes.DomoGrant.DomoGrant.__post_init__": (
                "classes/domogrant.html#domogrant.__post_init__",
                "domolibrary/classes/DomoGrant.py",
            ),
            "domolibrary.classes.DomoGrant.DomoGrant._from_json": (
                "classes/domogrant.html#domogrant._from_json",
                "domolibrary/classes/DomoGrant.py",
            ),
            "domolibrary.classes.DomoGrant.DomoGrants": (
                "classes/domogrant.html#domogrants",
                "domolibrary/classes/DomoGrant.py",
            ),
            "domolibrary.classes.DomoGrant.DomoGrants.get_grants": (
                "classes/domogrant.html#domogrants.get_grants",
                "domolibrary/classes/DomoGrant.py",
            ),
        },
        "domolibrary.classes.DomoGroup": {
            "domolibrary.classes.DomoGroup.DomoGroup": (
                "classes/domogroup.html#domogroup",
                "domolibrary/classes/DomoGroup.py",
            ),
            "domolibrary.classes.DomoGroup.DomoGroup.__post_init__": (
                "classes/domogroup.html#domogroup.__post_init__",
                "domolibrary/classes/DomoGroup.py",
            ),
            "domolibrary.classes.DomoGroup.DomoGroup._from_group_json": (
                "classes/domogroup.html#domogroup._from_group_json",
                "domolibrary/classes/DomoGroup.py",
            ),
            "domolibrary.classes.DomoGroup.DomoGroup._from_grouplist_json": (
                "classes/domogroup.html#domogroup._from_grouplist_json",
                "domolibrary/classes/DomoGroup.py",
            ),
            "domolibrary.classes.DomoGroup.DomoGroup._groups_to_domo_group": (
                "classes/domogroup.html#domogroup._groups_to_domo_group",
                "domolibrary/classes/DomoGroup.py",
            ),
            "domolibrary.classes.DomoGroup.DomoGroup.create_from_name": (
                "classes/domogroup.html#domogroup.create_from_name",
                "domolibrary/classes/DomoGroup.py",
            ),
            "domolibrary.classes.DomoGroup.DomoGroup.delete": (
                "classes/domogroup.html#domogroup.delete",
                "domolibrary/classes/DomoGroup.py",
            ),
            "domolibrary.classes.DomoGroup.DomoGroup.get_by_id": (
                "classes/domogroup.html#domogroup.get_by_id",
                "domolibrary/classes/DomoGroup.py",
            ),
            "domolibrary.classes.DomoGroup.DomoGroup.search_by_name": (
                "classes/domogroup.html#domogroup.search_by_name",
                "domolibrary/classes/DomoGroup.py",
            ),
            "domolibrary.classes.DomoGroup.DomoGroup.update_metadata": (
                "classes/domogroup.html#domogroup.update_metadata",
                "domolibrary/classes/DomoGroup.py",
            ),
            "domolibrary.classes.DomoGroup.DomoGroup.upsert": (
                "classes/domogroup.html#domogroup.upsert",
                "domolibrary/classes/DomoGroup.py",
            ),
            "domolibrary.classes.DomoGroup.DomoGroups": (
                "classes/domogroup.html#domogroups",
                "domolibrary/classes/DomoGroup.py",
            ),
            "domolibrary.classes.DomoGroup.DomoGroups.__init__": (
                "classes/domogroup.html#domogroups.__init__",
                "domolibrary/classes/DomoGroup.py",
            ),
            "domolibrary.classes.DomoGroup.DomoGroups._groups_to_domo_group": (
                "classes/domogroup.html#domogroups._groups_to_domo_group",
                "domolibrary/classes/DomoGroup.py",
            ),
            "domolibrary.classes.DomoGroup.DomoGroups.get_all_groups": (
                "classes/domogroup.html#domogroups.get_all_groups",
                "domolibrary/classes/DomoGroup.py",
            ),
            "domolibrary.classes.DomoGroup.DomoGroups.toggle_system_group_visibility": (
                "classes/domogroup.html#domogroups.toggle_system_group_visibility",
                "domolibrary/classes/DomoGroup.py",
            ),
        },
        "domolibrary.classes.DomoGroup_Membership": {
            "domolibrary.classes.DomoGroup_Membership.GroupMembership": (
                "classes/domogroup_membership.html#groupmembership",
                "domolibrary/classes/DomoGroup_Membership.py",
            ),
            "domolibrary.classes.DomoGroup_Membership.GroupMembership.__init__": (
                "classes/domogroup_membership.html#groupmembership.__init__",
                "domolibrary/classes/DomoGroup_Membership.py",
            ),
            "domolibrary.classes.DomoGroup_Membership.GroupMembership._add_member": (
                "classes/domogroup_membership.html#groupmembership._add_member",
                "domolibrary/classes/DomoGroup_Membership.py",
            ),
            "domolibrary.classes.DomoGroup_Membership.GroupMembership._add_owner": (
                "classes/domogroup_membership.html#groupmembership._add_owner",
                "domolibrary/classes/DomoGroup_Membership.py",
            ),
            "domolibrary.classes.DomoGroup_Membership.GroupMembership._add_to_list": (
                "classes/domogroup_membership.html#groupmembership._add_to_list",
                "domolibrary/classes/DomoGroup_Membership.py",
            ),
            "domolibrary.classes.DomoGroup_Membership.GroupMembership._remove_member": (
                "classes/domogroup_membership.html#groupmembership._remove_member",
                "domolibrary/classes/DomoGroup_Membership.py",
            ),
            "domolibrary.classes.DomoGroup_Membership.GroupMembership._remove_owner": (
                "classes/domogroup_membership.html#groupmembership._remove_owner",
                "domolibrary/classes/DomoGroup_Membership.py",
            ),
            "domolibrary.classes.DomoGroup_Membership.GroupMembership._reset_obj": (
                "classes/domogroup_membership.html#groupmembership._reset_obj",
                "domolibrary/classes/DomoGroup_Membership.py",
            ),
            "domolibrary.classes.DomoGroup_Membership.GroupMembership._update_group_access": (
                "classes/domogroup_membership.html#groupmembership._update_group_access",
                "domolibrary/classes/DomoGroup_Membership.py",
            ),
            "domolibrary.classes.DomoGroup_Membership.GroupMembership.add_members": (
                "classes/domogroup_membership.html#groupmembership.add_members",
                "domolibrary/classes/DomoGroup_Membership.py",
            ),
            "domolibrary.classes.DomoGroup_Membership.GroupMembership.add_owner_manage_groups_role": (
                "classes/domogroup_membership.html#groupmembership.add_owner_manage_groups_role",
                "domolibrary/classes/DomoGroup_Membership.py",
            ),
            "domolibrary.classes.DomoGroup_Membership.GroupMembership.add_owners": (
                "classes/domogroup_membership.html#groupmembership.add_owners",
                "domolibrary/classes/DomoGroup_Membership.py",
            ),
            "domolibrary.classes.DomoGroup_Membership.GroupMembership.get_members": (
                "classes/domogroup_membership.html#groupmembership.get_members",
                "domolibrary/classes/DomoGroup_Membership.py",
            ),
            "domolibrary.classes.DomoGroup_Membership.GroupMembership.get_owners": (
                "classes/domogroup_membership.html#groupmembership.get_owners",
                "domolibrary/classes/DomoGroup_Membership.py",
            ),
            "domolibrary.classes.DomoGroup_Membership.GroupMembership.remove_members": (
                "classes/domogroup_membership.html#groupmembership.remove_members",
                "domolibrary/classes/DomoGroup_Membership.py",
            ),
            "domolibrary.classes.DomoGroup_Membership.GroupMembership.remove_owners": (
                "classes/domogroup_membership.html#groupmembership.remove_owners",
                "domolibrary/classes/DomoGroup_Membership.py",
            ),
            "domolibrary.classes.DomoGroup_Membership.GroupMembership.set_members": (
                "classes/domogroup_membership.html#groupmembership.set_members",
                "domolibrary/classes/DomoGroup_Membership.py",
            ),
            "domolibrary.classes.DomoGroup_Membership.GroupMembership.set_owners": (
                "classes/domogroup_membership.html#groupmembership.set_owners",
                "domolibrary/classes/DomoGroup_Membership.py",
            ),
            "domolibrary.classes.DomoGroup_Membership.UpdateGroupMembership": (
                "classes/domogroup_membership.html#updategroupmembership",
                "domolibrary/classes/DomoGroup_Membership.py",
            ),
            "domolibrary.classes.DomoGroup_Membership.UpdateGroupMembership.__init__": (
                "classes/domogroup_membership.html#updategroupmembership.__init__",
                "domolibrary/classes/DomoGroup_Membership.py",
            ),
        },
        "domolibrary.classes.DomoInstanceConfig": {
            "domolibrary.classes.DomoInstanceConfig.DomoConnector": (
                "classes/domoinstanceconfig.html#domoconnector",
                "domolibrary/classes/DomoInstanceConfig.py",
            ),
            "domolibrary.classes.DomoInstanceConfig.DomoConnector._from_str": (
                "classes/domoinstanceconfig.html#domoconnector._from_str",
                "domolibrary/classes/DomoInstanceConfig.py",
            ),
            "domolibrary.classes.DomoInstanceConfig.DomoInstanceConfig": (
                "classes/domoinstanceconfig.html#domoinstanceconfig",
                "domolibrary/classes/DomoInstanceConfig.py",
            ),
            "domolibrary.classes.DomoInstanceConfig.DomoInstanceConfig.__post_init__": (
                "classes/domoinstanceconfig.html#domoinstanceconfig.__post_init__",
                "domolibrary/classes/DomoInstanceConfig.py",
            ),
            "domolibrary.classes.DomoInstanceConfig.DomoInstanceConfig.generate_access_token": (
                "classes/domoinstanceconfig.html#domoinstanceconfig.generate_access_token",
                "domolibrary/classes/DomoInstanceConfig.py",
            ),
            "domolibrary.classes.DomoInstanceConfig.DomoInstanceConfig.generate_applications_report": (
                "classes/domoinstanceconfig.html#domoinstanceconfig.generate_applications_report",
                "domolibrary/classes/DomoInstanceConfig.py",
            ),
            "domolibrary.classes.DomoInstanceConfig.DomoInstanceConfig.get_access_tokens": (
                "classes/domoinstanceconfig.html#domoinstanceconfig.get_access_tokens",
                "domolibrary/classes/DomoInstanceConfig.py",
            ),
            "domolibrary.classes.DomoInstanceConfig.DomoInstanceConfig.get_allowlist": (
                "classes/domoinstanceconfig.html#domoinstanceconfig.get_allowlist",
                "domolibrary/classes/DomoInstanceConfig.py",
            ),
            "domolibrary.classes.DomoInstanceConfig.DomoInstanceConfig.get_applications": (
                "classes/domoinstanceconfig.html#domoinstanceconfig.get_applications",
                "domolibrary/classes/DomoInstanceConfig.py",
            ),
            "domolibrary.classes.DomoInstanceConfig.DomoInstanceConfig.get_authorized_custom_app_domains": (
                "classes/domoinstanceconfig.html#domoinstanceconfig.get_authorized_custom_app_domains",
                "domolibrary/classes/DomoInstanceConfig.py",
            ),
            "domolibrary.classes.DomoInstanceConfig.DomoInstanceConfig.get_authorized_domains": (
                "classes/domoinstanceconfig.html#domoinstanceconfig.get_authorized_domains",
                "domolibrary/classes/DomoInstanceConfig.py",
            ),
            "domolibrary.classes.DomoInstanceConfig.DomoInstanceConfig.get_connectors": (
                "classes/domoinstanceconfig.html#domoinstanceconfig.get_connectors",
                "domolibrary/classes/DomoInstanceConfig.py",
            ),
            "domolibrary.classes.DomoInstanceConfig.DomoInstanceConfig.get_grants": (
                "classes/domoinstanceconfig.html#domoinstanceconfig.get_grants",
                "domolibrary/classes/DomoInstanceConfig.py",
            ),
            "domolibrary.classes.DomoInstanceConfig.DomoInstanceConfig.get_is_invite_social_users_enabled": (
                "classes/domoinstanceconfig.html#domoinstanceconfig.get_is_invite_social_users_enabled",
                "domolibrary/classes/DomoInstanceConfig.py",
            ),
            "domolibrary.classes.DomoInstanceConfig.DomoInstanceConfig.get_is_user_invite_notification_enabled": (
                "classes/domoinstanceconfig.html#domoinstanceconfig.get_is_user_invite_notification_enabled",
                "domolibrary/classes/DomoInstanceConfig.py",
            ),
            "domolibrary.classes.DomoInstanceConfig.DomoInstanceConfig.get_is_weekly_digest_enabled": (
                "classes/domoinstanceconfig.html#domoinstanceconfig.get_is_weekly_digest_enabled",
                "domolibrary/classes/DomoInstanceConfig.py",
            ),
            "domolibrary.classes.DomoInstanceConfig.DomoInstanceConfig.get_publications": (
                "classes/domoinstanceconfig.html#domoinstanceconfig.get_publications",
                "domolibrary/classes/DomoInstanceConfig.py",
            ),
            "domolibrary.classes.DomoInstanceConfig.DomoInstanceConfig.get_roles": (
                "classes/domoinstanceconfig.html#domoinstanceconfig.get_roles",
                "domolibrary/classes/DomoInstanceConfig.py",
            ),
            "domolibrary.classes.DomoInstanceConfig.DomoInstanceConfig.get_sandbox_is_same_instance_promotion_enabled": (
                "classes/domoinstanceconfig.html#domoinstanceconfig.get_sandbox_is_same_instance_promotion_enabled",
                "domolibrary/classes/DomoInstanceConfig.py",
            ),
            "domolibrary.classes.DomoInstanceConfig.DomoInstanceConfig.get_sso_config": (
                "classes/domoinstanceconfig.html#domoinstanceconfig.get_sso_config",
                "domolibrary/classes/DomoInstanceConfig.py",
            ),
            "domolibrary.classes.DomoInstanceConfig.DomoInstanceConfig.regenerate_access_token": (
                "classes/domoinstanceconfig.html#domoinstanceconfig.regenerate_access_token",
                "domolibrary/classes/DomoInstanceConfig.py",
            ),
            "domolibrary.classes.DomoInstanceConfig.DomoInstanceConfig.set_allowlist": (
                "classes/domoinstanceconfig.html#domoinstanceconfig.set_allowlist",
                "domolibrary/classes/DomoInstanceConfig.py",
            ),
            "domolibrary.classes.DomoInstanceConfig.DomoInstanceConfig.set_authorized_custom_app_domains": (
                "classes/domoinstanceconfig.html#domoinstanceconfig.set_authorized_custom_app_domains",
                "domolibrary/classes/DomoInstanceConfig.py",
            ),
            "domolibrary.classes.DomoInstanceConfig.DomoInstanceConfig.set_authorized_domains": (
                "classes/domoinstanceconfig.html#domoinstanceconfig.set_authorized_domains",
                "domolibrary/classes/DomoInstanceConfig.py",
            ),
            "domolibrary.classes.DomoInstanceConfig.DomoInstanceConfig.toggle_is_invite_social_users_enabled": (
                "classes/domoinstanceconfig.html#domoinstanceconfig.toggle_is_invite_social_users_enabled",
                "domolibrary/classes/DomoInstanceConfig.py",
            ),
            "domolibrary.classes.DomoInstanceConfig.DomoInstanceConfig.toggle_is_user_invite_notification_enabled": (
                "classes/domoinstanceconfig.html#domoinstanceconfig.toggle_is_user_invite_notification_enabled",
                "domolibrary/classes/DomoInstanceConfig.py",
            ),
            "domolibrary.classes.DomoInstanceConfig.DomoInstanceConfig.toggle_is_weekly_digest_enabled": (
                "classes/domoinstanceconfig.html#domoinstanceconfig.toggle_is_weekly_digest_enabled",
                "domolibrary/classes/DomoInstanceConfig.py",
            ),
            "domolibrary.classes.DomoInstanceConfig.DomoInstanceConfig.toggle_sandbox_allow_same_instance_promotion": (
                "classes/domoinstanceconfig.html#domoinstanceconfig.toggle_sandbox_allow_same_instance_promotion",
                "domolibrary/classes/DomoInstanceConfig.py",
            ),
            "domolibrary.classes.DomoInstanceConfig.DomoInstanceConfig.update_sso_config": (
                "classes/domoinstanceconfig.html#domoinstanceconfig.update_sso_config",
                "domolibrary/classes/DomoInstanceConfig.py",
            ),
            "domolibrary.classes.DomoInstanceConfig.DomoInstanceConfig.upsert_allowlist": (
                "classes/domoinstanceconfig.html#domoinstanceconfig.upsert_allowlist",
                "domolibrary/classes/DomoInstanceConfig.py",
            ),
            "domolibrary.classes.DomoInstanceConfig.DomoInstanceConfig.upsert_authorized_custom_app_domains": (
                "classes/domoinstanceconfig.html#domoinstanceconfig.upsert_authorized_custom_app_domains",
                "domolibrary/classes/DomoInstanceConfig.py",
            ),
            "domolibrary.classes.DomoInstanceConfig.DomoInstanceConfig.upsert_authorized_domains": (
                "classes/domoinstanceconfig.html#domoinstanceconfig.upsert_authorized_domains",
                "domolibrary/classes/DomoInstanceConfig.py",
            ),
            "domolibrary.classes.DomoInstanceConfig.SSO_Config": (
                "classes/domoinstanceconfig.html#sso_config",
                "domolibrary/classes/DomoInstanceConfig.py",
            ),
            "domolibrary.classes.DomoInstanceConfig.SSO_Config._from_json": (
                "classes/domoinstanceconfig.html#sso_config._from_json",
                "domolibrary/classes/DomoInstanceConfig.py",
            ),
            "domolibrary.classes.DomoInstanceConfig.SSO_Config.add_attribute": (
                "classes/domoinstanceconfig.html#sso_config.add_attribute",
                "domolibrary/classes/DomoInstanceConfig.py",
            ),
            "domolibrary.classes.DomoInstanceConfig.SSO_Config.to_json": (
                "classes/domoinstanceconfig.html#sso_config.to_json",
                "domolibrary/classes/DomoInstanceConfig.py",
            ),
        },
        "domolibrary.classes.DomoInstanceConfig_UserAttribute": {
            "domolibrary.classes.DomoInstanceConfig_UserAttribute.UserAttribute": (
                "classes/domoinstanceconfig_userattributes.html#userattribute",
                "domolibrary/classes/DomoInstanceConfig_UserAttribute.py",
            ),
            "domolibrary.classes.DomoInstanceConfig_UserAttribute.UserAttribute.__eq__": (
                "classes/domoinstanceconfig_userattributes.html#userattribute.__eq__",
                "domolibrary/classes/DomoInstanceConfig_UserAttribute.py",
            ),
            "domolibrary.classes.DomoInstanceConfig_UserAttribute.UserAttribute._from_json": (
                "classes/domoinstanceconfig_userattributes.html#userattribute._from_json",
                "domolibrary/classes/DomoInstanceConfig_UserAttribute.py",
            ),
            "domolibrary.classes.DomoInstanceConfig_UserAttribute.UserAttribute.get_by_id": (
                "classes/domoinstanceconfig_userattributes.html#userattribute.get_by_id",
                "domolibrary/classes/DomoInstanceConfig_UserAttribute.py",
            ),
            "domolibrary.classes.DomoInstanceConfig_UserAttribute.UserAttribute.update": (
                "classes/domoinstanceconfig_userattributes.html#userattribute.update",
                "domolibrary/classes/DomoInstanceConfig_UserAttribute.py",
            ),
            "domolibrary.classes.DomoInstanceConfig_UserAttribute.UserAttributes": (
                "classes/domoinstanceconfig_userattributes.html#userattributes",
                "domolibrary/classes/DomoInstanceConfig_UserAttribute.py",
            ),
            "domolibrary.classes.DomoInstanceConfig_UserAttribute.UserAttributes.create": (
                "classes/domoinstanceconfig_userattributes.html#userattributes.create",
                "domolibrary/classes/DomoInstanceConfig_UserAttribute.py",
            ),
            "domolibrary.classes.DomoInstanceConfig_UserAttribute.UserAttributes.delete": (
                "classes/domoinstanceconfig_userattributes.html#userattributes.delete",
                "domolibrary/classes/DomoInstanceConfig_UserAttribute.py",
            ),
            "domolibrary.classes.DomoInstanceConfig_UserAttribute.UserAttributes.get_attributes": (
                "classes/domoinstanceconfig_userattributes.html#userattributes.get_attributes",
                "domolibrary/classes/DomoInstanceConfig_UserAttribute.py",
            ),
            "domolibrary.classes.DomoInstanceConfig_UserAttribute.UserAttributes.upsert": (
                "classes/domoinstanceconfig_userattributes.html#userattributes.upsert",
                "domolibrary/classes/DomoInstanceConfig_UserAttribute.py",
            ),
        },
        "domolibrary.classes.DomoJupyter": {
            "domolibrary.classes.DomoJupyter.DomoJupyterWorkspace": (
                "classes/domojupyter.html#domojupyterworkspace",
                "domolibrary/classes/DomoJupyter.py",
            ),
            "domolibrary.classes.DomoJupyter.DomoJupyterWorkspace.__post_init__": (
                "classes/domojupyter.html#domojupyterworkspace.__post_init__",
                "domolibrary/classes/DomoJupyter.py",
            ),
            "domolibrary.classes.DomoJupyter.DomoJupyterWorkspace._from_json": (
                "classes/domojupyter.html#domojupyterworkspace._from_json",
                "domolibrary/classes/DomoJupyter.py",
            ),
            "domolibrary.classes.DomoJupyter.DomoJupyterWorkspace._update_auth_params": (
                "classes/domojupyter.html#domojupyterworkspace._update_auth_params",
                "domolibrary/classes/DomoJupyter.py",
            ),
            "domolibrary.classes.DomoJupyter.DomoJupyterWorkspace.get_by_id": (
                "classes/domojupyter.html#domojupyterworkspace.get_by_id",
                "domolibrary/classes/DomoJupyter.py",
            ),
            "domolibrary.classes.DomoJupyter.DomoJupyterWorkspace.get_content": (
                "classes/domojupyter.html#domojupyterworkspace.get_content",
                "domolibrary/classes/DomoJupyter.py",
            ),
            "domolibrary.classes.DomoJupyter.DomoJupyterWorkspace.update_auth": (
                "classes/domojupyter.html#domojupyterworkspace.update_auth",
                "domolibrary/classes/DomoJupyter.py",
            ),
            "domolibrary.classes.DomoJupyter.DomoJupyterWorkspace_Content": (
                "classes/domojupyter.html#domojupyterworkspace_content",
                "domolibrary/classes/DomoJupyter.py",
            ),
            "domolibrary.classes.DomoJupyter.DomoJupyterWorkspace_Content.__post_init__": (
                "classes/domojupyter.html#domojupyterworkspace_content.__post_init__",
                "domolibrary/classes/DomoJupyter.py",
            ),
            "domolibrary.classes.DomoJupyter.DomoJupyterWorkspace_Content._from_json": (
                "classes/domojupyter.html#domojupyterworkspace_content._from_json",
                "domolibrary/classes/DomoJupyter.py",
            ),
            "domolibrary.classes.DomoJupyter.DomoJupyterWorkspace_Content.export": (
                "classes/domojupyter.html#domojupyterworkspace_content.export",
                "domolibrary/classes/DomoJupyter.py",
            ),
            "domolibrary.classes.DomoJupyter.DomoJupyterWorkspace_Content.update": (
                "classes/domojupyter.html#domojupyterworkspace_content.update",
                "domolibrary/classes/DomoJupyter.py",
            ),
        },
        "domolibrary.classes.DomoLineage": {
            "domolibrary.classes.DomoLineage.DomoLineage": (
                "classes/domolineage.html#domolineage",
                "domolibrary/classes/DomoLineage.py",
            ),
            "domolibrary.classes.DomoLineage.DomoLineage.__post_init__": (
                "classes/domolineage.html#domolineage.__post_init__",
                "domolibrary/classes/DomoLineage.py",
            ),
            "domolibrary.classes.DomoLineage.DomoLineage._flatten_lineage": (
                "classes/domolineage.html#domolineage._flatten_lineage",
                "domolibrary/classes/DomoLineage.py",
            ),
            "domolibrary.classes.DomoLineage.DomoLineage._get_content_list_ls": (
                "classes/domolineage.html#domolineage._get_content_list_ls",
                "domolibrary/classes/DomoLineage.py",
            ),
            "domolibrary.classes.DomoLineage.DomoLineage._get_page_card_ids": (
                "classes/domolineage.html#domolineage._get_page_card_ids",
                "domolibrary/classes/DomoLineage.py",
            ),
            "domolibrary.classes.DomoLineage.DomoLineage._reset_lineage_and_sync_parent": (
                "classes/domolineage.html#domolineage._reset_lineage_and_sync_parent",
                "domolibrary/classes/DomoLineage.py",
            ),
            "domolibrary.classes.DomoLineage.DomoLineage.get": (
                "classes/domolineage.html#domolineage.get",
                "domolibrary/classes/DomoLineage.py",
            ),
            "domolibrary.classes.DomoLineage.DomoLineage.get_entity_lineage_upstream": (
                "classes/domolineage.html#domolineage.get_entity_lineage_upstream",
                "domolibrary/classes/DomoLineage.py",
            ),
            "domolibrary.classes.DomoLineage.DomoLineage_Type": (
                "classes/domolineage.html#domolineage_type",
                "domolibrary/classes/DomoLineage.py",
            ),
        },
        "domolibrary.classes.DomoPDP": {
            "domolibrary.classes.DomoPDP.Dataset_PDP_Policies": (
                "classes/domopdp.html#dataset_pdp_policies",
                "domolibrary/classes/DomoPDP.py",
            ),
            "domolibrary.classes.DomoPDP.Dataset_PDP_Policies.__init__": (
                "classes/domopdp.html#dataset_pdp_policies.__init__",
                "domolibrary/classes/DomoPDP.py",
            ),
            "domolibrary.classes.DomoPDP.Dataset_PDP_Policies.get_policies": (
                "classes/domopdp.html#dataset_pdp_policies.get_policies",
                "domolibrary/classes/DomoPDP.py",
            ),
            "domolibrary.classes.DomoPDP.Dataset_PDP_Policies.search_pdp_policies": (
                "classes/domopdp.html#dataset_pdp_policies.search_pdp_policies",
                "domolibrary/classes/DomoPDP.py",
            ),
            "domolibrary.classes.DomoPDP.Dataset_PDP_Policies.toggle_dataset_pdp": (
                "classes/domopdp.html#dataset_pdp_policies.toggle_dataset_pdp",
                "domolibrary/classes/DomoPDP.py",
            ),
            "domolibrary.classes.DomoPDP.PDP_Parameter": (
                "classes/domopdp.html#pdp_parameter",
                "domolibrary/classes/DomoPDP.py",
            ),
            "domolibrary.classes.DomoPDP.PDP_Parameter.generate_body_from_parameter": (
                "classes/domopdp.html#pdp_parameter.generate_body_from_parameter",
                "domolibrary/classes/DomoPDP.py",
            ),
            "domolibrary.classes.DomoPDP.PDP_Parameter.generate_parameter_simple": (
                "classes/domopdp.html#pdp_parameter.generate_parameter_simple",
                "domolibrary/classes/DomoPDP.py",
            ),
            "domolibrary.classes.DomoPDP.PDP_Policy": (
                "classes/domopdp.html#pdp_policy",
                "domolibrary/classes/DomoPDP.py",
            ),
            "domolibrary.classes.DomoPDP.PDP_Policy._from_json": (
                "classes/domopdp.html#pdp_policy._from_json",
                "domolibrary/classes/DomoPDP.py",
            ),
            "domolibrary.classes.DomoPDP.PDP_Policy.delete_policy": (
                "classes/domopdp.html#pdp_policy.delete_policy",
                "domolibrary/classes/DomoPDP.py",
            ),
            "domolibrary.classes.DomoPDP.PDP_Policy.generate_body_from_policy": (
                "classes/domopdp.html#pdp_policy.generate_body_from_policy",
                "domolibrary/classes/DomoPDP.py",
            ),
            "domolibrary.classes.DomoPDP.PDP_Policy.upsert_policy": (
                "classes/domopdp.html#pdp_policy.upsert_policy",
                "domolibrary/classes/DomoPDP.py",
            ),
            "domolibrary.classes.DomoPDP.SearchPDP_NotFound": (
                "classes/domopdp.html#searchpdp_notfound",
                "domolibrary/classes/DomoPDP.py",
            ),
            "domolibrary.classes.DomoPDP.SearchPDP_NotFound.__init__": (
                "classes/domopdp.html#searchpdp_notfound.__init__",
                "domolibrary/classes/DomoPDP.py",
            ),
        },
        "domolibrary.classes.DomoPage": {
            "domolibrary.classes.DomoPage.DomoPage": (
                "classes/domopage.html#domopage",
                "domolibrary/classes/DomoPage.py",
            ),
            "domolibrary.classes.DomoPage.DomoPage._from_adminsummary": (
                "classes/domopage.html#domopage._from_adminsummary",
                "domolibrary/classes/DomoPage.py",
            ),
            "domolibrary.classes.DomoPage.DomoPage._from_bootstrap": (
                "classes/domopage.html#domopage._from_bootstrap",
                "domolibrary/classes/DomoPage.py",
            ),
            "domolibrary.classes.DomoPage.DomoPage._from_content_stacks_v3": (
                "classes/domopage.html#domopage._from_content_stacks_v3",
                "domolibrary/classes/DomoPage.py",
            ),
            "domolibrary.classes.DomoPage.DomoPage._get_domo_owners_from_dd": (
                "classes/domopage.html#domopage._get_domo_owners_from_dd",
                "domolibrary/classes/DomoPage.py",
            ),
            "domolibrary.classes.DomoPage.DomoPage.add_page_owner": (
                "classes/domopage.html#domopage.add_page_owner",
                "domolibrary/classes/DomoPage.py",
            ),
            "domolibrary.classes.DomoPage.DomoPage.display_url": (
                "classes/domopage.html#domopage.display_url",
                "domolibrary/classes/DomoPage.py",
            ),
            "domolibrary.classes.DomoPage.DomoPage.flatten_children": (
                "classes/domopage.html#domopage.flatten_children",
                "domolibrary/classes/DomoPage.py",
            ),
            "domolibrary.classes.DomoPage.DomoPage.get_accesslist": (
                "classes/domopage.html#domopage.get_accesslist",
                "domolibrary/classes/DomoPage.py",
            ),
            "domolibrary.classes.DomoPage.DomoPage.get_by_id": (
                "classes/domopage.html#domopage.get_by_id",
                "domolibrary/classes/DomoPage.py",
            ),
            "domolibrary.classes.DomoPage.DomoPage.get_cards": (
                "classes/domopage.html#domopage.get_cards",
                "domolibrary/classes/DomoPage.py",
            ),
            "domolibrary.classes.DomoPage.DomoPage.get_children": (
                "classes/domopage.html#domopage.get_children",
                "domolibrary/classes/DomoPage.py",
            ),
            "domolibrary.classes.DomoPage.DomoPage.get_datasets": (
                "classes/domopage.html#domopage.get_datasets",
                "domolibrary/classes/DomoPage.py",
            ),
            "domolibrary.classes.DomoPage.DomoPage.get_parent_hierarchy": (
                "classes/domopage.html#domopage.get_parent_hierarchy",
                "domolibrary/classes/DomoPage.py",
            ),
            "domolibrary.classes.DomoPage.DomoPage.share": (
                "classes/domopage.html#domopage.share",
                "domolibrary/classes/DomoPage.py",
            ),
            "domolibrary.classes.DomoPage.DomoPage.test_page_access": (
                "classes/domopage.html#domopage.test_page_access",
                "domolibrary/classes/DomoPage.py",
            ),
            "domolibrary.classes.DomoPage.DomoPage.update_layout": (
                "classes/domopage.html#domopage.update_layout",
                "domolibrary/classes/DomoPage.py",
            ),
            "domolibrary.classes.DomoPage.DomoPage_GetRecursive": (
                "classes/domopage.html#domopage_getrecursive",
                "domolibrary/classes/DomoPage.py",
            ),
            "domolibrary.classes.DomoPage.DomoPage_GetRecursive.__init__": (
                "classes/domopage.html#domopage_getrecursive.__init__",
                "domolibrary/classes/DomoPage.py",
            ),
            "domolibrary.classes.DomoPage.DomoPages": (
                "classes/domopage.html#domopages",
                "domolibrary/classes/DomoPage.py",
            ),
            "domolibrary.classes.DomoPage.DomoPages.get_pages": (
                "classes/domopage.html#domopages.get_pages",
                "domolibrary/classes/DomoPage.py",
            ),
            "domolibrary.classes.DomoPage.Page_NoAccess": (
                "classes/domopage.html#page_noaccess",
                "domolibrary/classes/DomoPage.py",
            ),
            "domolibrary.classes.DomoPage.Page_NoAccess.__init__": (
                "classes/domopage.html#page_noaccess.__init__",
                "domolibrary/classes/DomoPage.py",
            ),
        },
        "domolibrary.classes.DomoPage_Content": {
            "domolibrary.classes.DomoPage_Content.PageLayout": (
                "classes/domopage_content.html#pagelayout",
                "domolibrary/classes/DomoPage_Content.py",
            ),
            "domolibrary.classes.DomoPage_Content.PageLayout._from_json": (
                "classes/domopage_content.html#pagelayout._from_json",
                "domolibrary/classes/DomoPage_Content.py",
            ),
            "domolibrary.classes.DomoPage_Content.PageLayout.generate_new_background_body": (
                "classes/domopage_content.html#pagelayout.generate_new_background_body",
                "domolibrary/classes/DomoPage_Content.py",
            ),
            "domolibrary.classes.DomoPage_Content.PageLayout.get_body": (
                "classes/domopage_content.html#pagelayout.get_body",
                "domolibrary/classes/DomoPage_Content.py",
            ),
            "domolibrary.classes.DomoPage_Content.PageLayoutBackground": (
                "classes/domopage_content.html#pagelayoutbackground",
                "domolibrary/classes/DomoPage_Content.py",
            ),
            "domolibrary.classes.DomoPage_Content.PageLayoutBackground._from_json": (
                "classes/domopage_content.html#pagelayoutbackground._from_json",
                "domolibrary/classes/DomoPage_Content.py",
            ),
            "domolibrary.classes.DomoPage_Content.PageLayoutBackground.get_body": (
                "classes/domopage_content.html#pagelayoutbackground.get_body",
                "domolibrary/classes/DomoPage_Content.py",
            ),
            "domolibrary.classes.DomoPage_Content.PageLayoutCompact": (
                "classes/domopage_content.html#pagelayoutcompact",
                "domolibrary/classes/DomoPage_Content.py",
            ),
            "domolibrary.classes.DomoPage_Content.PageLayoutCompact._from_json": (
                "classes/domopage_content.html#pagelayoutcompact._from_json",
                "domolibrary/classes/DomoPage_Content.py",
            ),
            "domolibrary.classes.DomoPage_Content.PageLayoutContent": (
                "classes/domopage_content.html#pagelayoutcontent",
                "domolibrary/classes/DomoPage_Content.py",
            ),
            "domolibrary.classes.DomoPage_Content.PageLayoutContent._from_json": (
                "classes/domopage_content.html#pagelayoutcontent._from_json",
                "domolibrary/classes/DomoPage_Content.py",
            ),
            "domolibrary.classes.DomoPage_Content.PageLayoutContent.get_body": (
                "classes/domopage_content.html#pagelayoutcontent.get_body",
                "domolibrary/classes/DomoPage_Content.py",
            ),
            "domolibrary.classes.DomoPage_Content.PageLayoutStandard": (
                "classes/domopage_content.html#pagelayoutstandard",
                "domolibrary/classes/DomoPage_Content.py",
            ),
            "domolibrary.classes.DomoPage_Content.PageLayoutStandard._from_json": (
                "classes/domopage_content.html#pagelayoutstandard._from_json",
                "domolibrary/classes/DomoPage_Content.py",
            ),
            "domolibrary.classes.DomoPage_Content.PageLayoutTemplate": (
                "classes/domopage_content.html#pagelayouttemplate",
                "domolibrary/classes/DomoPage_Content.py",
            ),
            "domolibrary.classes.DomoPage_Content.PageLayoutTemplate._from_json": (
                "classes/domopage_content.html#pagelayouttemplate._from_json",
                "domolibrary/classes/DomoPage_Content.py",
            ),
            "domolibrary.classes.DomoPage_Content.PageLayoutTemplate.get_body": (
                "classes/domopage_content.html#pagelayouttemplate.get_body",
                "domolibrary/classes/DomoPage_Content.py",
            ),
        },
        "domolibrary.classes.DomoPublish": {
            "domolibrary.classes.DomoPublish.DomoPublication": (
                "classes/domopublish.html#domopublication",
                "domolibrary/classes/DomoPublish.py",
            ),
            "domolibrary.classes.DomoPublish.DomoPublication.__post_init__": (
                "classes/domopublish.html#domopublication.__post_init__",
                "domolibrary/classes/DomoPublish.py",
            ),
            "domolibrary.classes.DomoPublish.DomoPublication._from_json": (
                "classes/domopublish.html#domopublication._from_json",
                "domolibrary/classes/DomoPublish.py",
            ),
            "domolibrary.classes.DomoPublish.DomoPublication.accept_invite_by_id": (
                "classes/domopublish.html#domopublication.accept_invite_by_id",
                "domolibrary/classes/DomoPublish.py",
            ),
            "domolibrary.classes.DomoPublish.DomoPublication.convert_content_to_dataframe": (
                "classes/domopublish.html#domopublication.convert_content_to_dataframe",
                "domolibrary/classes/DomoPublish.py",
            ),
            "domolibrary.classes.DomoPublish.DomoPublication.convert_lineage_to_dataframe": (
                "classes/domopublish.html#domopublication.convert_lineage_to_dataframe",
                "domolibrary/classes/DomoPublish.py",
            ),
            "domolibrary.classes.DomoPublish.DomoPublication.create_publication": (
                "classes/domopublish.html#domopublication.create_publication",
                "domolibrary/classes/DomoPublish.py",
            ),
            "domolibrary.classes.DomoPublish.DomoPublication.get_from_id": (
                "classes/domopublish.html#domopublication.get_from_id",
                "domolibrary/classes/DomoPublish.py",
            ),
            "domolibrary.classes.DomoPublish.DomoPublication.get_subscription_invites_list": (
                "classes/domopublish.html#domopublication.get_subscription_invites_list",
                "domolibrary/classes/DomoPublish.py",
            ),
            "domolibrary.classes.DomoPublish.DomoPublication.update_publication": (
                "classes/domopublish.html#domopublication.update_publication",
                "domolibrary/classes/DomoPublish.py",
            ),
            "domolibrary.classes.DomoPublish.DomoPublication_Content": (
                "classes/domopublish.html#domopublication_content",
                "domolibrary/classes/DomoPublish.py",
            ),
            "domolibrary.classes.DomoPublish.DomoPublication_Content._from_json": (
                "classes/domopublish.html#domopublication_content._from_json",
                "domolibrary/classes/DomoPublish.py",
            ),
            "domolibrary.classes.DomoPublish.DomoPublication_Content.to_api_json": (
                "classes/domopublish.html#domopublication_content.to_api_json",
                "domolibrary/classes/DomoPublish.py",
            ),
            "domolibrary.classes.DomoPublish.DomoPublication_Subscription": (
                "classes/domopublish.html#domopublication_subscription",
                "domolibrary/classes/DomoPublish.py",
            ),
            "domolibrary.classes.DomoPublish.DomoPublication_Subscription._from_json": (
                "classes/domopublish.html#domopublication_subscription._from_json",
                "domolibrary/classes/DomoPublish.py",
            ),
            "domolibrary.classes.DomoPublish.DomoPublication_UnexpectedContentType": (
                "classes/domopublish.html#domopublication_unexpectedcontenttype",
                "domolibrary/classes/DomoPublish.py",
            ),
            "domolibrary.classes.DomoPublish.DomoPublication_UnexpectedContentType.__init__": (
                "classes/domopublish.html#domopublication_unexpectedcontenttype.__init__",
                "domolibrary/classes/DomoPublish.py",
            ),
            "domolibrary.classes.DomoPublish.DomoPublications": (
                "classes/domopublish.html#domopublications",
                "domolibrary/classes/DomoPublish.py",
            ),
            "domolibrary.classes.DomoPublish.DomoPublications.get_subscription_summaries": (
                "classes/domopublish.html#domopublications.get_subscription_summaries",
                "domolibrary/classes/DomoPublish.py",
            ),
            "domolibrary.classes.DomoPublish.DomoPublications.search_publications": (
                "classes/domopublish.html#domopublications.search_publications",
                "domolibrary/classes/DomoPublish.py",
            ),
        },
        "domolibrary.classes.DomoRole": {
            "domolibrary.classes.DomoRole.AddUser_Error": (
                "classes/domorole.html#adduser_error",
                "domolibrary/classes/DomoRole.py",
            ),
            "domolibrary.classes.DomoRole.AddUser_Error.__init__": (
                "classes/domorole.html#adduser_error.__init__",
                "domolibrary/classes/DomoRole.py",
            ),
            "domolibrary.classes.DomoRole.CreateRole_Error": (
                "classes/domorole.html#createrole_error",
                "domolibrary/classes/DomoRole.py",
            ),
            "domolibrary.classes.DomoRole.CreateRole_Error.__init__": (
                "classes/domorole.html#createrole_error.__init__",
                "domolibrary/classes/DomoRole.py",
            ),
            "domolibrary.classes.DomoRole.DeleteRole_Error": (
                "classes/domorole.html#deleterole_error",
                "domolibrary/classes/DomoRole.py",
            ),
            "domolibrary.classes.DomoRole.DeleteRole_Error.__init__": (
                "classes/domorole.html#deleterole_error.__init__",
                "domolibrary/classes/DomoRole.py",
            ),
            "domolibrary.classes.DomoRole.DomoRole": (
                "classes/domorole.html#domorole",
                "domolibrary/classes/DomoRole.py",
            ),
            "domolibrary.classes.DomoRole.DomoRole.__post_init__": (
                "classes/domorole.html#domorole.__post_init__",
                "domolibrary/classes/DomoRole.py",
            ),
            "domolibrary.classes.DomoRole.DomoRole._from_json": (
                "classes/domorole.html#domorole._from_json",
                "domolibrary/classes/DomoRole.py",
            ),
            "domolibrary.classes.DomoRole.DomoRole._valid_grant_ls": (
                "classes/domorole.html#domorole._valid_grant_ls",
                "domolibrary/classes/DomoRole.py",
            ),
            "domolibrary.classes.DomoRole.DomoRole.add_user": (
                "classes/domorole.html#domorole.add_user",
                "domolibrary/classes/DomoRole.py",
            ),
            "domolibrary.classes.DomoRole.DomoRole.delete_role": (
                "classes/domorole.html#domorole.delete_role",
                "domolibrary/classes/DomoRole.py",
            ),
            "domolibrary.classes.DomoRole.DomoRole.get_by_id": (
                "classes/domorole.html#domorole.get_by_id",
                "domolibrary/classes/DomoRole.py",
            ),
            "domolibrary.classes.DomoRole.DomoRole.get_grants": (
                "classes/domorole.html#domorole.get_grants",
                "domolibrary/classes/DomoRole.py",
            ),
            "domolibrary.classes.DomoRole.DomoRole.get_membership": (
                "classes/domorole.html#domorole.get_membership",
                "domolibrary/classes/DomoRole.py",
            ),
            "domolibrary.classes.DomoRole.DomoRole.set_as_default_role": (
                "classes/domorole.html#domorole.set_as_default_role",
                "domolibrary/classes/DomoRole.py",
            ),
            "domolibrary.classes.DomoRole.DomoRole.set_grants": (
                "classes/domorole.html#domorole.set_grants",
                "domolibrary/classes/DomoRole.py",
            ),
            "domolibrary.classes.DomoRole.DomoRole.update_role_metadata": (
                "classes/domorole.html#domorole.update_role_metadata",
                "domolibrary/classes/DomoRole.py",
            ),
            "domolibrary.classes.DomoRole.DomoRoles": (
                "classes/domorole.html#domoroles",
                "domolibrary/classes/DomoRole.py",
            ),
            "domolibrary.classes.DomoRole.DomoRoles.create_role": (
                "classes/domorole.html#domoroles.create_role",
                "domolibrary/classes/DomoRole.py",
            ),
            "domolibrary.classes.DomoRole.DomoRoles.get_roles": (
                "classes/domorole.html#domoroles.get_roles",
                "domolibrary/classes/DomoRole.py",
            ),
            "domolibrary.classes.DomoRole.DomoRoles.search_role": (
                "classes/domorole.html#domoroles.search_role",
                "domolibrary/classes/DomoRole.py",
            ),
            "domolibrary.classes.DomoRole.DomoRoles.upsert_role": (
                "classes/domorole.html#domoroles.upsert_role",
                "domolibrary/classes/DomoRole.py",
            ),
            "domolibrary.classes.DomoRole.SearchRole_NotFound": (
                "classes/domorole.html#searchrole_notfound",
                "domolibrary/classes/DomoRole.py",
            ),
            "domolibrary.classes.DomoRole.SearchRole_NotFound.__init__": (
                "classes/domorole.html#searchrole_notfound.__init__",
                "domolibrary/classes/DomoRole.py",
            ),
            "domolibrary.classes.DomoRole.SetRoleGrants_MissingGrants": (
                "classes/domorole.html#setrolegrants_missinggrants",
                "domolibrary/classes/DomoRole.py",
            ),
            "domolibrary.classes.DomoRole.SetRoleGrants_MissingGrants.__init__": (
                "classes/domorole.html#setrolegrants_missinggrants.__init__",
                "domolibrary/classes/DomoRole.py",
            ),
        },
        "domolibrary.classes.DomoSandbox": {
            "domolibrary.classes.DomoSandbox.DomoRepository": (
                "classes/domosandbox.html#domorepository",
                "domolibrary/classes/DomoSandbox.py",
            ),
            "domolibrary.classes.DomoSandbox.DomoRepository.__post_init__": (
                "classes/domosandbox.html#domorepository.__post_init__",
                "domolibrary/classes/DomoSandbox.py",
            ),
            "domolibrary.classes.DomoSandbox.DomoRepository._from_json": (
                "classes/domosandbox.html#domorepository._from_json",
                "domolibrary/classes/DomoSandbox.py",
            ),
            "domolibrary.classes.DomoSandbox.DomoRepository.convert_lineage_to_dataframe": (
                "classes/domosandbox.html#domorepository.convert_lineage_to_dataframe",
                "domolibrary/classes/DomoSandbox.py",
            ),
            "domolibrary.classes.DomoSandbox.DomoRepository.get_from_id": (
                "classes/domosandbox.html#domorepository.get_from_id",
                "domolibrary/classes/DomoSandbox.py",
            ),
            "domolibrary.classes.DomoSandbox.DomoSandbox": (
                "classes/domosandbox.html#domosandbox",
                "domolibrary/classes/DomoSandbox.py",
            ),
            "domolibrary.classes.DomoSandbox.DomoSandbox.get_repositories": (
                "classes/domosandbox.html#domosandbox.get_repositories",
                "domolibrary/classes/DomoSandbox.py",
            ),
            "domolibrary.classes.DomoSandbox.InvalidRepositoryError": (
                "classes/domosandbox.html#invalidrepositoryerror",
                "domolibrary/classes/DomoSandbox.py",
            ),
        },
        "domolibrary.classes.DomoStream": {
            "domolibrary.classes.DomoStream.DomoStream": (
                "classes/domostream.html#domostream",
                "domolibrary/classes/DomoStream.py",
            ),
            "domolibrary.classes.DomoStream.DomoStream.create_stream": (
                "classes/domostream.html#domostream.create_stream",
                "domolibrary/classes/DomoStream.py",
            ),
            "domolibrary.classes.DomoStream.DomoStream.get_stream_by_id": (
                "classes/domostream.html#domostream.get_stream_by_id",
                "domolibrary/classes/DomoStream.py",
            ),
            "domolibrary.classes.DomoStream.DomoStream.update_stream": (
                "classes/domostream.html#domostream.update_stream",
                "domolibrary/classes/DomoStream.py",
            ),
            "domolibrary.classes.DomoStream.DomoStream.upsert_connector": (
                "classes/domostream.html#domostream.upsert_connector",
                "domolibrary/classes/DomoStream.py",
            ),
            "domolibrary.classes.DomoStream.StreamConfig": (
                "classes/domostream.html#streamconfig",
                "domolibrary/classes/DomoStream.py",
            ),
        },
        "domolibrary.classes.DomoUser": {
            "domolibrary.classes.DomoUser.CreateUser_MissingRole": (
                "classes/domouser.html#createuser_missingrole",
                "domolibrary/classes/DomoUser.py",
            ),
            "domolibrary.classes.DomoUser.CreateUser_MissingRole.__init__": (
                "classes/domouser.html#createuser_missingrole.__init__",
                "domolibrary/classes/DomoUser.py",
            ),
            "domolibrary.classes.DomoUser.DeleteUser_Error": (
                "classes/domouser.html#deleteuser_error",
                "domolibrary/classes/DomoUser.py",
            ),
            "domolibrary.classes.DomoUser.DeleteUser_Error.__init__": (
                "classes/domouser.html#deleteuser_error.__init__",
                "domolibrary/classes/DomoUser.py",
            ),
            "domolibrary.classes.DomoUser.DomoUser": (
                "classes/domouser.html#domouser",
                "domolibrary/classes/DomoUser.py",
            ),
            "domolibrary.classes.DomoUser.DomoUser.__eq__": (
                "classes/domouser.html#domouser.__eq__",
                "domolibrary/classes/DomoUser.py",
            ),
            "domolibrary.classes.DomoUser.DomoUser.__post_init__": (
                "classes/domouser.html#domouser.__post_init__",
                "domolibrary/classes/DomoUser.py",
            ),
            "domolibrary.classes.DomoUser.DomoUser._from_bootstrap_json": (
                "classes/domouser.html#domouser._from_bootstrap_json",
                "domolibrary/classes/DomoUser.py",
            ),
            "domolibrary.classes.DomoUser.DomoUser._from_search_json": (
                "classes/domouser.html#domouser._from_search_json",
                "domolibrary/classes/DomoUser.py",
            ),
            "domolibrary.classes.DomoUser.DomoUser._from_virtual_json": (
                "classes/domouser.html#domouser._from_virtual_json",
                "domolibrary/classes/DomoUser.py",
            ),
            "domolibrary.classes.DomoUser.DomoUser.delete_user": (
                "classes/domouser.html#domouser.delete_user",
                "domolibrary/classes/DomoUser.py",
            ),
            "domolibrary.classes.DomoUser.DomoUser.download_avatar": (
                "classes/domouser.html#domouser.download_avatar",
                "domolibrary/classes/DomoUser.py",
            ),
            "domolibrary.classes.DomoUser.DomoUser.get_by_id": (
                "classes/domouser.html#domouser.get_by_id",
                "domolibrary/classes/DomoUser.py",
            ),
            "domolibrary.classes.DomoUser.DomoUser.get_role": (
                "classes/domouser.html#domouser.get_role",
                "domolibrary/classes/DomoUser.py",
            ),
            "domolibrary.classes.DomoUser.DomoUser.request_password_reset": (
                "classes/domouser.html#domouser.request_password_reset",
                "domolibrary/classes/DomoUser.py",
            ),
            "domolibrary.classes.DomoUser.DomoUser.reset_password": (
                "classes/domouser.html#domouser.reset_password",
                "domolibrary/classes/DomoUser.py",
            ),
            "domolibrary.classes.DomoUser.DomoUser.set_user_landing_page": (
                "classes/domouser.html#domouser.set_user_landing_page",
                "domolibrary/classes/DomoUser.py",
            ),
            "domolibrary.classes.DomoUser.DomoUser.update_properties": (
                "classes/domouser.html#domouser.update_properties",
                "domolibrary/classes/DomoUser.py",
            ),
            "domolibrary.classes.DomoUser.DomoUser.upload_avatar": (
                "classes/domouser.html#domouser.upload_avatar",
                "domolibrary/classes/DomoUser.py",
            ),
            "domolibrary.classes.DomoUser.DomoUser.upsert_avatar": (
                "classes/domouser.html#domouser.upsert_avatar",
                "domolibrary/classes/DomoUser.py",
            ),
            "domolibrary.classes.DomoUser.DomoUsers": (
                "classes/domouser.html#domousers",
                "domolibrary/classes/DomoUser.py",
            ),
            "domolibrary.classes.DomoUser.DomoUsers._generate_logger": (
                "classes/domouser.html#domousers._generate_logger",
                "domolibrary/classes/DomoUser.py",
            ),
            "domolibrary.classes.DomoUser.DomoUsers._users_to_domo_user": (
                "classes/domouser.html#domousers._users_to_domo_user",
                "domolibrary/classes/DomoUser.py",
            ),
            "domolibrary.classes.DomoUser.DomoUsers._users_to_virtual_user": (
                "classes/domouser.html#domousers._users_to_virtual_user",
                "domolibrary/classes/DomoUser.py",
            ),
            "domolibrary.classes.DomoUser.DomoUsers.all_users": (
                "classes/domouser.html#domousers.all_users",
                "domolibrary/classes/DomoUser.py",
            ),
            "domolibrary.classes.DomoUser.DomoUsers.by_email": (
                "classes/domouser.html#domousers.by_email",
                "domolibrary/classes/DomoUser.py",
            ),
            "domolibrary.classes.DomoUser.DomoUsers.by_id": (
                "classes/domouser.html#domousers.by_id",
                "domolibrary/classes/DomoUser.py",
            ),
            "domolibrary.classes.DomoUser.DomoUsers.create_user": (
                "classes/domouser.html#domousers.create_user",
                "domolibrary/classes/DomoUser.py",
            ),
            "domolibrary.classes.DomoUser.DomoUsers.upsert_user": (
                "classes/domouser.html#domousers.upsert_user",
                "domolibrary/classes/DomoUser.py",
            ),
            "domolibrary.classes.DomoUser.DomoUsers.util_match_domo_users_to_emails": (
                "classes/domouser.html#domousers.util_match_domo_users_to_emails",
                "domolibrary/classes/DomoUser.py",
            ),
            "domolibrary.classes.DomoUser.DomoUsers.util_match_users_obj_to_emails": (
                "classes/domouser.html#domousers.util_match_users_obj_to_emails",
                "domolibrary/classes/DomoUser.py",
            ),
            "domolibrary.classes.DomoUser.DomoUsers.virtual_user_by_subscriber_instance": (
                "classes/domouser.html#domousers.virtual_user_by_subscriber_instance",
                "domolibrary/classes/DomoUser.py",
            ),
            "domolibrary.classes.DomoUser.DownloadAvatar_NoAvatarKey": (
                "classes/domouser.html#downloadavatar_noavatarkey",
                "domolibrary/classes/DomoUser.py",
            ),
            "domolibrary.classes.DomoUser.DownloadAvatar_NoAvatarKey.__init__": (
                "classes/domouser.html#downloadavatar_noavatarkey.__init__",
                "domolibrary/classes/DomoUser.py",
            ),
        },
        "domolibrary.client.DomoAuth": {
            "domolibrary.client.DomoAuth.DomoAuth": (
                "client/domoauth.html#domoauth",
                "domolibrary/client/DomoAuth.py",
            ),
            "domolibrary.client.DomoAuth.DomoDeveloperAuth": (
                "client/domoauth.html#domodeveloperauth",
                "domolibrary/client/DomoAuth.py",
            ),
            "domolibrary.client.DomoAuth.DomoDeveloperAuth.generate_auth_header": (
                "client/domoauth.html#domodeveloperauth.generate_auth_header",
                "domolibrary/client/DomoAuth.py",
            ),
            "domolibrary.client.DomoAuth.DomoDeveloperAuth.get_auth_token": (
                "client/domoauth.html#domodeveloperauth.get_auth_token",
                "domolibrary/client/DomoAuth.py",
            ),
            "domolibrary.client.DomoAuth.DomoFullAuth": (
                "client/domoauth.html#domofullauth",
                "domolibrary/client/DomoAuth.py",
            ),
            "domolibrary.client.DomoAuth.DomoFullAuth._generate_auth_header": (
                "client/domoauth.html#domofullauth._generate_auth_header",
                "domolibrary/client/DomoAuth.py",
            ),
            "domolibrary.client.DomoAuth.DomoFullAuth.generate_auth_header": (
                "client/domoauth.html#domofullauth.generate_auth_header",
                "domolibrary/client/DomoAuth.py",
            ),
            "domolibrary.client.DomoAuth.DomoFullAuth.get_auth_token": (
                "client/domoauth.html#domofullauth.get_auth_token",
                "domolibrary/client/DomoAuth.py",
            ),
            "domolibrary.client.DomoAuth.DomoJupyterAuth": (
                "client/domoauth.html#domojupyterauth",
                "domolibrary/client/DomoAuth.py",
            ),
            "domolibrary.client.DomoAuth.DomoJupyterFullAuth": (
                "client/domoauth.html#domojupyterfullauth",
                "domolibrary/client/DomoAuth.py",
            ),
            "domolibrary.client.DomoAuth.DomoJupyterFullAuth.convert_auth": (
                "client/domoauth.html#domojupyterfullauth.convert_auth",
                "domolibrary/client/DomoAuth.py",
            ),
            "domolibrary.client.DomoAuth.DomoJupyterFullAuth.generate_auth_header": (
                "client/domoauth.html#domojupyterfullauth.generate_auth_header",
                "domolibrary/client/DomoAuth.py",
            ),
            "domolibrary.client.DomoAuth.DomoJupyterTokenAuth": (
                "client/domoauth.html#domojupytertokenauth",
                "domolibrary/client/DomoAuth.py",
            ),
            "domolibrary.client.DomoAuth.DomoJupyterTokenAuth.convert_auth": (
                "client/domoauth.html#domojupytertokenauth.convert_auth",
                "domolibrary/client/DomoAuth.py",
            ),
            "domolibrary.client.DomoAuth.DomoJupyterTokenAuth.generate_auth_header": (
                "client/domoauth.html#domojupytertokenauth.generate_auth_header",
                "domolibrary/client/DomoAuth.py",
            ),
            "domolibrary.client.DomoAuth.DomoTokenAuth": (
                "client/domoauth.html#domotokenauth",
                "domolibrary/client/DomoAuth.py",
            ),
            "domolibrary.client.DomoAuth.DomoTokenAuth._generate_auth_header": (
                "client/domoauth.html#domotokenauth._generate_auth_header",
                "domolibrary/client/DomoAuth.py",
            ),
            "domolibrary.client.DomoAuth.DomoTokenAuth.generate_auth_header": (
                "client/domoauth.html#domotokenauth.generate_auth_header",
                "domolibrary/client/DomoAuth.py",
            ),
            "domolibrary.client.DomoAuth.DomoTokenAuth.get_auth_token": (
                "client/domoauth.html#domotokenauth.get_auth_token",
                "domolibrary/client/DomoAuth.py",
            ),
            "domolibrary.client.DomoAuth._DomoAuth_Optional": (
                "client/domoauth.html#_domoauth_optional",
                "domolibrary/client/DomoAuth.py",
            ),
            "domolibrary.client.DomoAuth._DomoAuth_Optional.generate_auth_header": (
                "client/domoauth.html#_domoauth_optional.generate_auth_header",
                "domolibrary/client/DomoAuth.py",
            ),
            "domolibrary.client.DomoAuth._DomoAuth_Optional.get_auth_token": (
                "client/domoauth.html#_domoauth_optional.get_auth_token",
                "domolibrary/client/DomoAuth.py",
            ),
            "domolibrary.client.DomoAuth._DomoAuth_Required": (
                "client/domoauth.html#_domoauth_required",
                "domolibrary/client/DomoAuth.py",
            ),
            "domolibrary.client.DomoAuth._DomoAuth_Required.__post_init__": (
                "client/domoauth.html#_domoauth_required.__post_init__",
                "domolibrary/client/DomoAuth.py",
            ),
            "domolibrary.client.DomoAuth._DomoAuth_Required.print_is_token": (
                "client/domoauth.html#_domoauth_required.print_is_token",
                "domolibrary/client/DomoAuth.py",
            ),
            "domolibrary.client.DomoAuth._DomoAuth_Required.set_manual_login": (
                "client/domoauth.html#_domoauth_required.set_manual_login",
                "domolibrary/client/DomoAuth.py",
            ),
            "domolibrary.client.DomoAuth._DomoAuth_Required.who_am_i": (
                "client/domoauth.html#_domoauth_required.who_am_i",
                "domolibrary/client/DomoAuth.py",
            ),
            "domolibrary.client.DomoAuth._DomoDeveloperAuth_Optional": (
                "client/domoauth.html#_domodeveloperauth_optional",
                "domolibrary/client/DomoAuth.py",
            ),
            "domolibrary.client.DomoAuth._DomoDeveloperAuth_Required": (
                "client/domoauth.html#_domodeveloperauth_required",
                "domolibrary/client/DomoAuth.py",
            ),
            "domolibrary.client.DomoAuth._DomoFullAuth_Required": (
                "client/domoauth.html#_domofullauth_required",
                "domolibrary/client/DomoAuth.py",
            ),
            "domolibrary.client.DomoAuth._DomoJupyter_Optional": (
                "client/domoauth.html#_domojupyter_optional",
                "domolibrary/client/DomoAuth.py",
            ),
            "domolibrary.client.DomoAuth._DomoJupyter_Optional.__post_init__": (
                "client/domoauth.html#_domojupyter_optional.__post_init__",
                "domolibrary/client/DomoAuth.py",
            ),
            "domolibrary.client.DomoAuth._DomoJupyter_Required": (
                "client/domoauth.html#_domojupyter_required",
                "domolibrary/client/DomoAuth.py",
            ),
            "domolibrary.client.DomoAuth._DomoJupyter_Required._test_prereq": (
                "client/domoauth.html#_domojupyter_required._test_prereq",
                "domolibrary/client/DomoAuth.py",
            ),
            "domolibrary.client.DomoAuth._DomoJupyter_Required.get_jupyter_token_flow": (
                "client/domoauth.html#_domojupyter_required.get_jupyter_token_flow",
                "domolibrary/client/DomoAuth.py",
            ),
            "domolibrary.client.DomoAuth._DomoTokenAuth_Required": (
                "client/domoauth.html#_domotokenauth_required",
                "domolibrary/client/DomoAuth.py",
            ),
            "domolibrary.client.DomoAuth._DomoTokenAuth_Required.who_am_i": (
                "client/domoauth.html#_domotokenauth_required.who_am_i",
                "domolibrary/client/DomoAuth.py",
            ),
            "domolibrary.client.DomoAuth.test_is_full_auth": (
                "client/domoauth.html#test_is_full_auth",
                "domolibrary/client/DomoAuth.py",
            ),
            "domolibrary.client.DomoAuth.test_is_jupyter_auth": (
                "client/domoauth.html#test_is_jupyter_auth",
                "domolibrary/client/DomoAuth.py",
            ),
        },
        "domolibrary.client.DomoError": {
            "domolibrary.client.DomoError.AuthNotProvidedError": (
                "client/domoerror.html#authnotprovidederror",
                "domolibrary/client/DomoError.py",
            ),
            "domolibrary.client.DomoError.AuthNotProvidedError.__init__": (
                "client/domoerror.html#authnotprovidederror.__init__",
                "domolibrary/client/DomoError.py",
            ),
            "domolibrary.client.DomoError.DatasetNotProvidedError": (
                "client/domoerror.html#datasetnotprovidederror",
                "domolibrary/client/DomoError.py",
            ),
            "domolibrary.client.DomoError.DatasetNotProvidedError.__init__": (
                "client/domoerror.html#datasetnotprovidederror.__init__",
                "domolibrary/client/DomoError.py",
            ),
            "domolibrary.client.DomoError.DomoError": (
                "client/domoerror.html#domoerror",
                "domolibrary/client/DomoError.py",
            ),
            "domolibrary.client.DomoError.DomoError.__init__": (
                "client/domoerror.html#domoerror.__init__",
                "domolibrary/client/DomoError.py",
            ),
        },
        "domolibrary.client.Logger": {
            "domolibrary.client.Logger.Logger": (
                "client/logger.html#logger",
                "domolibrary/client/Logger.py",
            ),
            "domolibrary.client.Logger.Logger.__init__": (
                "client/logger.html#logger.__init__",
                "domolibrary/client/Logger.py",
            ),
            "domolibrary.client.Logger.Logger._add_crumb": (
                "client/logger.html#logger._add_crumb",
                "domolibrary/client/Logger.py",
            ),
            "domolibrary.client.Logger.Logger._add_log": (
                "client/logger.html#logger._add_log",
                "domolibrary/client/Logger.py",
            ),
            "domolibrary.client.Logger.Logger._remove_crumb": (
                "client/logger.html#logger._remove_crumb",
                "domolibrary/client/Logger.py",
            ),
            "domolibrary.client.Logger.Logger.get_traceback": (
                "client/logger.html#logger.get_traceback",
                "domolibrary/client/Logger.py",
            ),
            "domolibrary.client.Logger.Logger.log_error": (
                "client/logger.html#logger.log_error",
                "domolibrary/client/Logger.py",
            ),
            "domolibrary.client.Logger.Logger.log_info": (
                "client/logger.html#logger.log_info",
                "domolibrary/client/Logger.py",
            ),
            "domolibrary.client.Logger.Logger.log_warning": (
                "client/logger.html#logger.log_warning",
                "domolibrary/client/Logger.py",
            ),
            "domolibrary.client.Logger.Logger.output_log": (
                "client/logger.html#logger.output_log",
                "domolibrary/client/Logger.py",
            ),
            "domolibrary.client.Logger.TracebackDetails": (
                "client/logger.html#tracebackdetails",
                "domolibrary/client/Logger.py",
            ),
            "domolibrary.client.Logger.TracebackDetails.__init__": (
                "client/logger.html#tracebackdetails.__init__",
                "domolibrary/client/Logger.py",
            ),
            "domolibrary.client.Logger.get_traceback": (
                "client/logger.html#get_traceback",
                "domolibrary/client/Logger.py",
            ),
        },
        "domolibrary.client.ResponseGetData": {
            "domolibrary.client.ResponseGetData.BlockedByVPN": (
                "client/responsegetdata.html#blockedbyvpn",
                "domolibrary/client/ResponseGetData.py",
            ),
            "domolibrary.client.ResponseGetData.BlockedByVPN.__init__": (
                "client/responsegetdata.html#blockedbyvpn.__init__",
                "domolibrary/client/ResponseGetData.py",
            ),
            "domolibrary.client.ResponseGetData.ResponseGetData": (
                "client/responsegetdata.html#responsegetdata",
                "domolibrary/client/ResponseGetData.py",
            ),
            "domolibrary.client.ResponseGetData.ResponseGetData._from_aiohttp_response": (
                "client/responsegetdata.html#responsegetdata._from_aiohttp_response",
                "domolibrary/client/ResponseGetData.py",
            ),
            "domolibrary.client.ResponseGetData.ResponseGetData._from_httpx_response": (
                "client/responsegetdata.html#responsegetdata._from_httpx_response",
                "domolibrary/client/ResponseGetData.py",
            ),
            "domolibrary.client.ResponseGetData.ResponseGetData._from_looper": (
                "client/responsegetdata.html#responsegetdata._from_looper",
                "domolibrary/client/ResponseGetData.py",
            ),
            "domolibrary.client.ResponseGetData.ResponseGetData._from_requests_response": (
                "client/responsegetdata.html#responsegetdata._from_requests_response",
                "domolibrary/client/ResponseGetData.py",
            ),
            "domolibrary.client.ResponseGetData.ResponseGetData.set_response": (
                "client/responsegetdata.html#responsegetdata.set_response",
                "domolibrary/client/ResponseGetData.py",
            ),
            "domolibrary.client.ResponseGetData._read_stream": (
                "client/responsegetdata.html#_read_stream",
                "domolibrary/client/ResponseGetData.py",
            ),
            "domolibrary.client.ResponseGetData._write_stream": (
                "client/responsegetdata.html#_write_stream",
                "domolibrary/client/ResponseGetData.py",
            ),
            "domolibrary.client.ResponseGetData.find_ip": (
                "client/responsegetdata.html#find_ip",
                "domolibrary/client/ResponseGetData.py",
            ),
        },
        "domolibrary.client.get_data": {
            "domolibrary.client.get_data.GetData_Error": (
                "client/get_data.html#getdata_error",
                "domolibrary/client/get_data.py",
            ),
            "domolibrary.client.get_data.GetData_Error.__init__": (
                "client/get_data.html#getdata_error.__init__",
                "domolibrary/client/get_data.py",
            ),
            "domolibrary.client.get_data.LooperError": (
                "client/get_data.html#loopererror",
                "domolibrary/client/get_data.py",
            ),
            "domolibrary.client.get_data.LooperError.__init__": (
                "client/get_data.html#loopererror.__init__",
                "domolibrary/client/get_data.py",
            ),
            "domolibrary.client.get_data.RouteFunction_ResponseTypeError": (
                "client/get_data.html#routefunction_responsetypeerror",
                "domolibrary/client/get_data.py",
            ),
            "domolibrary.client.get_data.RouteFunction_ResponseTypeError.__init__": (
                "client/get_data.html#routefunction_responsetypeerror.__init__",
                "domolibrary/client/get_data.py",
            ),
            "domolibrary.client.get_data.create_aiohttp_session": (
                "client/get_data.html#create_aiohttp_session",
                "domolibrary/client/get_data.py",
            ),
            "domolibrary.client.get_data.create_headers": (
                "client/get_data.html#create_headers",
                "domolibrary/client/get_data.py",
            ),
            "domolibrary.client.get_data.create_httpx_session": (
                "client/get_data.html#create_httpx_session",
                "domolibrary/client/get_data.py",
            ),
            "domolibrary.client.get_data.get_data": (
                "client/get_data.html#get_data",
                "domolibrary/client/get_data.py",
            ),
            "domolibrary.client.get_data.get_data_aiohttp": (
                "client/get_data.html#get_data_aiohttp",
                "domolibrary/client/get_data.py",
            ),
            "domolibrary.client.get_data.get_data_stream": (
                "client/get_data.html#get_data_stream",
                "domolibrary/client/get_data.py",
            ),
            "domolibrary.client.get_data.handle_error": (
                "client/get_data.html#handle_error",
                "domolibrary/client/get_data.py",
            ),
            "domolibrary.client.get_data.looper": (
                "client/get_data.html#looper",
                "domolibrary/client/get_data.py",
            ),
            "domolibrary.client.get_data.looper_aiohttp": (
                "client/get_data.html#looper_aiohttp",
                "domolibrary/client/get_data.py",
            ),
            "domolibrary.client.get_data.route_function": (
                "client/get_data.html#route_function",
                "domolibrary/client/get_data.py",
            ),
        },
        "domolibrary.integrations.Automation": {
            "domolibrary.integrations.Automation.get_company_domains": (
                "integrations/automation.html#get_company_domains",
                "domolibrary/integrations/Automation.py",
            ),
            "domolibrary.integrations.Automation.remove_partition_by_x_days": (
                "integrations/automation.html#remove_partition_by_x_days",
                "domolibrary/integrations/Automation.py",
            ),
        },
        "domolibrary.integrations.DomoJupyter": {
            "domolibrary.integrations.DomoJupyter.DomoJupyterAccount_InstanceAuth": (
                "integrations/domojupyter.html#domojupyteraccount_instanceauth",
                "domolibrary/integrations/DomoJupyter.py",
            ),
            "domolibrary.integrations.DomoJupyter.DomoJupyterAccount_InstanceAuth.__post_init__": (
                "integrations/domojupyter.html#domojupyteraccount_instanceauth.__post_init__",
                "domolibrary/integrations/DomoJupyter.py",
            ),
            "domolibrary.integrations.DomoJupyter.DomoJupyterAccount_InstanceAuth._clean_account_admin_accounts": (
                "integrations/domojupyter.html#domojupyteraccount_instanceauth._clean_account_admin_accounts",
                "domolibrary/integrations/DomoJupyter.py",
            ),
            "domolibrary.integrations.DomoJupyter.DomoJupyterAccount_InstanceAuth._set_display_name": (
                "integrations/domojupyter.html#domojupyteraccount_instanceauth._set_display_name",
                "domolibrary/integrations/DomoJupyter.py",
            ),
            "domolibrary.integrations.DomoJupyter.DomoJupyterAccount_InstanceAuth._test_regex_mask": (
                "integrations/domojupyter.html#domojupyteraccount_instanceauth._test_regex_mask",
                "domolibrary/integrations/DomoJupyter.py",
            ),
            "domolibrary.integrations.DomoJupyter.DomoJupyterAccount_InstanceAuth.generate_auth": (
                "integrations/domojupyter.html#domojupyteraccount_instanceauth.generate_auth",
                "domolibrary/integrations/DomoJupyter.py",
            ),
            "domolibrary.integrations.DomoJupyter.DomoJupyterAccount_InstanceAuth.generate_auth_ls": (
                "integrations/domojupyter.html#domojupyteraccount_instanceauth.generate_auth_ls",
                "domolibrary/integrations/DomoJupyter.py",
            ),
            "domolibrary.integrations.DomoJupyter.DomoJupyterAccount_InstanceAuth.get_domo_instance_auth_account": (
                "integrations/domojupyter.html#domojupyteraccount_instanceauth.get_domo_instance_auth_account",
                "domolibrary/integrations/DomoJupyter.py",
            ),
            "domolibrary.integrations.DomoJupyter.GenerateAuth_CredentialsNotProvided": (
                "integrations/domojupyter.html#generateauth_credentialsnotprovided",
                "domolibrary/integrations/DomoJupyter.py",
            ),
            "domolibrary.integrations.DomoJupyter.GenerateAuth_CredentialsNotProvided.__init__": (
                "integrations/domojupyter.html#generateauth_credentialsnotprovided.__init__",
                "domolibrary/integrations/DomoJupyter.py",
            ),
            "domolibrary.integrations.DomoJupyter.GenerateAuth_InvalidDomoInstanceList": (
                "integrations/domojupyter.html#generateauth_invaliddomoinstancelist",
                "domolibrary/integrations/DomoJupyter.py",
            ),
            "domolibrary.integrations.DomoJupyter.GenerateAuth_InvalidDomoInstanceList.__init__": (
                "integrations/domojupyter.html#generateauth_invaliddomoinstancelist.__init__",
                "domolibrary/integrations/DomoJupyter.py",
            ),
            "domolibrary.integrations.DomoJupyter.GetDomains_Query_AuthMatch_Error": (
                "integrations/domojupyter.html#getdomains_query_authmatch_error",
                "domolibrary/integrations/DomoJupyter.py",
            ),
            "domolibrary.integrations.DomoJupyter.GetDomains_Query_AuthMatch_Error.__init__": (
                "integrations/domojupyter.html#getdomains_query_authmatch_error.__init__",
                "domolibrary/integrations/DomoJupyter.py",
            ),
            "domolibrary.integrations.DomoJupyter.GetInstanceConfig": (
                "integrations/domojupyter.html#getinstanceconfig",
                "domolibrary/integrations/DomoJupyter.py",
            ),
            "domolibrary.integrations.DomoJupyter.GetInstanceConfig.__init__": (
                "integrations/domojupyter.html#getinstanceconfig.__init__",
                "domolibrary/integrations/DomoJupyter.py",
            ),
            "domolibrary.integrations.DomoJupyter.GetInstanceConfig._retrieve_company_ds": (
                "integrations/domojupyter.html#getinstanceconfig._retrieve_company_ds",
                "domolibrary/integrations/DomoJupyter.py",
            ),
            "domolibrary.integrations.DomoJupyter.GetInstanceConfig.get_domains_with_instance_auth": (
                "integrations/domojupyter.html#getinstanceconfig.get_domains_with_instance_auth",
                "domolibrary/integrations/DomoJupyter.py",
            ),
            "domolibrary.integrations.DomoJupyter.GetJupyter_ErrorRetrievingAccount": (
                "integrations/domojupyter.html#getjupyter_errorretrievingaccount",
                "domolibrary/integrations/DomoJupyter.py",
            ),
            "domolibrary.integrations.DomoJupyter.GetJupyter_ErrorRetrievingAccount.__init__": (
                "integrations/domojupyter.html#getjupyter_errorretrievingaccount.__init__",
                "domolibrary/integrations/DomoJupyter.py",
            ),
            "domolibrary.integrations.DomoJupyter.GetJupyter_ErrorRetrievingAccountProperty": (
                "integrations/domojupyter.html#getjupyter_errorretrievingaccountproperty",
                "domolibrary/integrations/DomoJupyter.py",
            ),
            "domolibrary.integrations.DomoJupyter.GetJupyter_ErrorRetrievingAccountProperty.__init__": (
                "integrations/domojupyter.html#getjupyter_errorretrievingaccountproperty.__init__",
                "domolibrary/integrations/DomoJupyter.py",
            ),
            "domolibrary.integrations.DomoJupyter.InvalidAccountNameError": (
                "integrations/domojupyter.html#invalidaccountnameerror",
                "domolibrary/integrations/DomoJupyter.py",
            ),
            "domolibrary.integrations.DomoJupyter.InvalidAccountNameError.__init__": (
                "integrations/domojupyter.html#invalidaccountnameerror.__init__",
                "domolibrary/integrations/DomoJupyter.py",
            ),
            "domolibrary.integrations.DomoJupyter.InvalidAccountTypeError": (
                "integrations/domojupyter.html#invalidaccounttypeerror",
                "domolibrary/integrations/DomoJupyter.py",
            ),
            "domolibrary.integrations.DomoJupyter.InvalidAccountTypeError.__init__": (
                "integrations/domojupyter.html#invalidaccounttypeerror.__init__",
                "domolibrary/integrations/DomoJupyter.py",
            ),
            "domolibrary.integrations.DomoJupyter.NoConfigCompanyError": (
                "integrations/domojupyter.html#noconfigcompanyerror",
                "domolibrary/integrations/DomoJupyter.py",
            ),
            "domolibrary.integrations.DomoJupyter.NoConfigCompanyError.__init__": (
                "integrations/domojupyter.html#noconfigcompanyerror.__init__",
                "domolibrary/integrations/DomoJupyter.py",
            ),
            "domolibrary.integrations.DomoJupyter.get_jupyter_account": (
                "integrations/domojupyter.html#get_jupyter_account",
                "domolibrary/integrations/DomoJupyter.py",
            ),
            "domolibrary.integrations.DomoJupyter.is_v2": (
                "integrations/domojupyter.html#is_v2",
                "domolibrary/integrations/DomoJupyter.py",
            ),
            "domolibrary.integrations.DomoJupyter.process_row": (
                "integrations/domojupyter.html#process_row",
                "domolibrary/integrations/DomoJupyter.py",
            ),
        },
        "domolibrary.integrations.MonitDataset": {
            "domolibrary.integrations.MonitDataset.MonitDataset_Data": (
                "integrations/monitdataset.html#monitdataset_data",
                "domolibrary/integrations/MonitDataset.py",
            ),
            "domolibrary.integrations.MonitDataset.MonitDataset_Record": (
                "integrations/monitdataset.html#monitdataset_record",
                "domolibrary/integrations/MonitDataset.py",
            ),
        },
        "domolibrary.integrations.RoleHierarchy": {
            "domolibrary.integrations.RoleHierarchy.calc_role": (
                "integrations/rolehierarchy.html#calc_role",
                "domolibrary/integrations/RoleHierarchy.py",
            ),
            "domolibrary.integrations.RoleHierarchy.extract_role_hierarchy": (
                "integrations/rolehierarchy.html#extract_role_hierarchy",
                "domolibrary/integrations/RoleHierarchy.py",
            ),
            "domolibrary.integrations.RoleHierarchy.get_roles_w_hierarchy": (
                "integrations/rolehierarchy.html#get_roles_w_hierarchy",
                "domolibrary/integrations/RoleHierarchy.py",
            ),
        },
        "domolibrary.routes.access_token": {
            "domolibrary.routes.access_token.AccessToken_GenerationError": (
                "routes/auth_accesstoken.html#accesstoken_generationerror",
                "domolibrary/routes/access_token.py",
            ),
            "domolibrary.routes.access_token.AccessToken_GenerationError.__init__": (
                "routes/auth_accesstoken.html#accesstoken_generationerror.__init__",
                "domolibrary/routes/access_token.py",
            ),
            "domolibrary.routes.access_token.AccessToken_RevokeError": (
                "routes/auth_accesstoken.html#accesstoken_revokeerror",
                "domolibrary/routes/access_token.py",
            ),
            "domolibrary.routes.access_token.AccessToken_RevokeError.__init__": (
                "routes/auth_accesstoken.html#accesstoken_revokeerror.__init__",
                "domolibrary/routes/access_token.py",
            ),
            "domolibrary.routes.access_token.generate_access_token": (
                "routes/auth_accesstoken.html#generate_access_token",
                "domolibrary/routes/access_token.py",
            ),
            "domolibrary.routes.access_token.generate_expiration_unixtimestamp": (
                "routes/auth_accesstoken.html#generate_expiration_unixtimestamp",
                "domolibrary/routes/access_token.py",
            ),
            "domolibrary.routes.access_token.get_access_tokens": (
                "routes/auth_accesstoken.html#get_access_tokens",
                "domolibrary/routes/access_token.py",
            ),
            "domolibrary.routes.access_token.revoke_access_token": (
                "routes/auth_accesstoken.html#revoke_access_token",
                "domolibrary/routes/access_token.py",
            ),
        },
        "domolibrary.routes.account": {
            "domolibrary.routes.account.CreateAccount_Error": (
                "routes/account.html#createaccount_error",
                "domolibrary/routes/account.py",
            ),
            "domolibrary.routes.account.CreateAccount_Error.__init__": (
                "routes/account.html#createaccount_error.__init__",
                "domolibrary/routes/account.py",
            ),
            "domolibrary.routes.account.DeleteAccount_Error": (
                "routes/account.html#deleteaccount_error",
                "domolibrary/routes/account.py",
            ),
            "domolibrary.routes.account.DeleteAccount_Error.__init__": (
                "routes/account.html#deleteaccount_error.__init__",
                "domolibrary/routes/account.py",
            ),
            "domolibrary.routes.account.GetAccount_NoConfigRetrieved": (
                "routes/account.html#getaccount_noconfigretrieved",
                "domolibrary/routes/account.py",
            ),
            "domolibrary.routes.account.GetAccount_NoConfigRetrieved.__init__": (
                "routes/account.html#getaccount_noconfigretrieved.__init__",
                "domolibrary/routes/account.py",
            ),
            "domolibrary.routes.account.GetAccount_NoMatch": (
                "routes/account.html#getaccount_nomatch",
                "domolibrary/routes/account.py",
            ),
            "domolibrary.routes.account.GetAccount_NoMatch.__init__": (
                "routes/account.html#getaccount_nomatch.__init__",
                "domolibrary/routes/account.py",
            ),
            "domolibrary.routes.account.ShareAccount": (
                "routes/account.html#shareaccount",
                "domolibrary/routes/account.py",
            ),
            "domolibrary.routes.account.ShareAccount_Error": (
                "routes/account.html#shareaccount_error",
                "domolibrary/routes/account.py",
            ),
            "domolibrary.routes.account.ShareAccount_Error.__init__": (
                "routes/account.html#shareaccount_error.__init__",
                "domolibrary/routes/account.py",
            ),
            "domolibrary.routes.account.ShareAccount_Error_AlreadyShared": (
                "routes/account.html#shareaccount_error_alreadyshared",
                "domolibrary/routes/account.py",
            ),
            "domolibrary.routes.account.ShareAccount_Error_AlreadyShared.__init__": (
                "routes/account.html#shareaccount_error_alreadyshared.__init__",
                "domolibrary/routes/account.py",
            ),
            "domolibrary.routes.account.ShareAccount_V1_AccessLevel": (
                "routes/account.html#shareaccount_v1_accesslevel",
                "domolibrary/routes/account.py",
            ),
            "domolibrary.routes.account.ShareAccount_V2_AccessLevel": (
                "routes/account.html#shareaccount_v2_accesslevel",
                "domolibrary/routes/account.py",
            ),
            "domolibrary.routes.account.UpdateAccount_Error": (
                "routes/account.html#updateaccount_error",
                "domolibrary/routes/account.py",
            ),
            "domolibrary.routes.account.UpdateAccount_Error.__init__": (
                "routes/account.html#updateaccount_error.__init__",
                "domolibrary/routes/account.py",
            ),
            "domolibrary.routes.account.create_account": (
                "routes/account.html#create_account",
                "domolibrary/routes/account.py",
            ),
            "domolibrary.routes.account.delete_account": (
                "routes/account.html#delete_account",
                "domolibrary/routes/account.py",
            ),
            "domolibrary.routes.account.generate_create_body": (
                "routes/account.html#generate_create_body",
                "domolibrary/routes/account.py",
            ),
            "domolibrary.routes.account.generate_share_account_payload_v1": (
                "routes/account.html#generate_share_account_payload_v1",
                "domolibrary/routes/account.py",
            ),
            "domolibrary.routes.account.generate_share_account_payload_v2": (
                "routes/account.html#generate_share_account_payload_v2",
                "domolibrary/routes/account.py",
            ),
            "domolibrary.routes.account.get_account_accesslist": (
                "routes/account.html#get_account_accesslist",
                "domolibrary/routes/account.py",
            ),
            "domolibrary.routes.account.get_account_config": (
                "routes/account.html#get_account_config",
                "domolibrary/routes/account.py",
            ),
            "domolibrary.routes.account.get_account_from_id": (
                "routes/account.html#get_account_from_id",
                "domolibrary/routes/account.py",
            ),
            "domolibrary.routes.account.get_accounts": (
                "routes/account.html#get_accounts",
                "domolibrary/routes/account.py",
            ),
            "domolibrary.routes.account.get_user_access": (
                "routes/account.html#get_user_access",
                "domolibrary/routes/account.py",
            ),
            "domolibrary.routes.account.share_account_v1": (
                "routes/account.html#share_account_v1",
                "domolibrary/routes/account.py",
            ),
            "domolibrary.routes.account.share_account_v2": (
                "routes/account.html#share_account_v2",
                "domolibrary/routes/account.py",
            ),
            "domolibrary.routes.account.update_account_config": (
                "routes/account.html#update_account_config",
                "domolibrary/routes/account.py",
            ),
            "domolibrary.routes.account.update_account_name": (
                "routes/account.html#update_account_name",
                "domolibrary/routes/account.py",
            ),
        },
        "domolibrary.routes.activity_log": {
            "domolibrary.routes.activity_log.get_activity_log_object_types": (
                "routes/activity_log.html#get_activity_log_object_types",
                "domolibrary/routes/activity_log.py",
            ),
            "domolibrary.routes.activity_log.search_activity_log": (
                "routes/activity_log.html#search_activity_log",
                "domolibrary/routes/activity_log.py",
            ),
        },
        "domolibrary.routes.application": {
            "domolibrary.routes.application.ApplicationError_NoJobRetrieved": (
                "routes/application.html#applicationerror_nojobretrieved",
                "domolibrary/routes/application.py",
            ),
            "domolibrary.routes.application.ApplicationError_NoJobRetrieved.__init__": (
                "routes/application.html#applicationerror_nojobretrieved.__init__",
                "domolibrary/routes/application.py",
            ),
            "domolibrary.routes.application.ApplicationError_NoneRetrieved": (
                "routes/application.html#applicationerror_noneretrieved",
                "domolibrary/routes/application.py",
            ),
            "domolibrary.routes.application.ApplicationError_NoneRetrieved.__init__": (
                "routes/application.html#applicationerror_noneretrieved.__init__",
                "domolibrary/routes/application.py",
            ),
            "domolibrary.routes.application.CRUD_ApplicationJob_Error": (
                "routes/application.html#crud_applicationjob_error",
                "domolibrary/routes/application.py",
            ),
            "domolibrary.routes.application.CRUD_ApplicationJob_Error.__init__": (
                "routes/application.html#crud_applicationjob_error.__init__",
                "domolibrary/routes/application.py",
            ),
            "domolibrary.routes.application.create_application_job": (
                "routes/application.html#create_application_job",
                "domolibrary/routes/application.py",
            ),
            "domolibrary.routes.application.execute_application_job": (
                "routes/application.html#execute_application_job",
                "domolibrary/routes/application.py",
            ),
            "domolibrary.routes.application.generate_body_watchdog_generic": (
                "routes/application.html#generate_body_watchdog_generic",
                "domolibrary/routes/application.py",
            ),
            "domolibrary.routes.application.generate_remote_domostats": (
                "routes/application.html#generate_remote_domostats",
                "domolibrary/routes/application.py",
            ),
            "domolibrary.routes.application.get_application_by_id": (
                "routes/application.html#get_application_by_id",
                "domolibrary/routes/application.py",
            ),
            "domolibrary.routes.application.get_application_job_by_id": (
                "routes/application.html#get_application_job_by_id",
                "domolibrary/routes/application.py",
            ),
            "domolibrary.routes.application.get_application_jobs": (
                "routes/application.html#get_application_jobs",
                "domolibrary/routes/application.py",
            ),
            "domolibrary.routes.application.get_applications": (
                "routes/application.html#get_applications",
                "domolibrary/routes/application.py",
            ),
            "domolibrary.routes.application.update_application_job": (
                "routes/application.html#update_application_job",
                "domolibrary/routes/application.py",
            ),
            "domolibrary.routes.application.update_application_job_trigger": (
                "routes/application.html#update_application_job_trigger",
                "domolibrary/routes/application.py",
            ),
        },
        "domolibrary.routes.auth": {
            "domolibrary.routes.auth.AccountLockedError": (
                "routes/auth.html#accountlockederror",
                "domolibrary/routes/auth.py",
            ),
            "domolibrary.routes.auth.AccountLockedError.__init__": (
                "routes/auth.html#accountlockederror.__init__",
                "domolibrary/routes/auth.py",
            ),
            "domolibrary.routes.auth.InvalidAuthTypeError": (
                "routes/auth.html#invalidauthtypeerror",
                "domolibrary/routes/auth.py",
            ),
            "domolibrary.routes.auth.InvalidAuthTypeError.__init__": (
                "routes/auth.html#invalidauthtypeerror.__init__",
                "domolibrary/routes/auth.py",
            ),
            "domolibrary.routes.auth.InvalidCredentialsError": (
                "routes/auth.html#invalidcredentialserror",
                "domolibrary/routes/auth.py",
            ),
            "domolibrary.routes.auth.InvalidCredentialsError.__init__": (
                "routes/auth.html#invalidcredentialserror.__init__",
                "domolibrary/routes/auth.py",
            ),
            "domolibrary.routes.auth.InvalidInstanceError": (
                "routes/auth.html#invalidinstanceerror",
                "domolibrary/routes/auth.py",
            ),
            "domolibrary.routes.auth.InvalidInstanceError.__init__": (
                "routes/auth.html#invalidinstanceerror.__init__",
                "domolibrary/routes/auth.py",
            ),
            "domolibrary.routes.auth.NoAccessTokenReturned": (
                "routes/auth.html#noaccesstokenreturned",
                "domolibrary/routes/auth.py",
            ),
            "domolibrary.routes.auth.NoAccessTokenReturned.__init__": (
                "routes/auth.html#noaccesstokenreturned.__init__",
                "domolibrary/routes/auth.py",
            ),
            "domolibrary.routes.auth.get_developer_auth": (
                "routes/auth.html#get_developer_auth",
                "domolibrary/routes/auth.py",
            ),
            "domolibrary.routes.auth.get_full_auth": (
                "routes/auth.html#get_full_auth",
                "domolibrary/routes/auth.py",
            ),
            "domolibrary.routes.auth.who_am_i": (
                "routes/auth.html#who_am_i",
                "domolibrary/routes/auth.py",
            ),
        },
        "domolibrary.routes.bootstrap": {
            "domolibrary.routes.bootstrap.Bootstrap_RetrievalError": (
                "routes/bootstrap.html#bootstrap_retrievalerror",
                "domolibrary/routes/bootstrap.py",
            ),
            "domolibrary.routes.bootstrap.Bootstrap_RetrievalError.__init__": (
                "routes/bootstrap.html#bootstrap_retrievalerror.__init__",
                "domolibrary/routes/bootstrap.py",
            ),
            "domolibrary.routes.bootstrap.get_bootstrap": (
                "routes/bootstrap.html#get_bootstrap",
                "domolibrary/routes/bootstrap.py",
            ),
            "domolibrary.routes.bootstrap.get_bootstrap_customerid": (
                "routes/bootstrap.html#get_bootstrap_customerid",
                "domolibrary/routes/bootstrap.py",
            ),
            "domolibrary.routes.bootstrap.get_bootstrap_features": (
                "routes/bootstrap.html#get_bootstrap_features",
                "domolibrary/routes/bootstrap.py",
            ),
            "domolibrary.routes.bootstrap.get_bootstrap_features_is_accountsv2_enabled": (
                "routes/bootstrap.html#get_bootstrap_features_is_accountsv2_enabled",
                "domolibrary/routes/bootstrap.py",
            ),
            "domolibrary.routes.bootstrap.get_bootstrap_pages": (
                "routes/bootstrap.html#get_bootstrap_pages",
                "domolibrary/routes/bootstrap.py",
            ),
        },
        "domolibrary.routes.card": {
            "domolibrary.routes.card.CardSearch_NotFoundError": (
                "routes/card.html#cardsearch_notfounderror",
                "domolibrary/routes/card.py",
            ),
            "domolibrary.routes.card.CardSearch_NotFoundError.__init__": (
                "routes/card.html#cardsearch_notfounderror.__init__",
                "domolibrary/routes/card.py",
            ),
            "domolibrary.routes.card.generate_body_search_cards_admin_summary": (
                "routes/card.html#generate_body_search_cards_admin_summary",
                "domolibrary/routes/card.py",
            ),
            "domolibrary.routes.card.get_card_metadata": (
                "routes/card.html#get_card_metadata",
                "domolibrary/routes/card.py",
            ),
            "domolibrary.routes.card.get_kpi_definition": (
                "routes/card.html#get_kpi_definition",
                "domolibrary/routes/card.py",
            ),
            "domolibrary.routes.card.search_cards_admin_summary": (
                "routes/card.html#search_cards_admin_summary",
                "domolibrary/routes/card.py",
            ),
        },
        "domolibrary.routes.datacenter": {
            "domolibrary.routes.datacenter.Datacenter_Enum": (
                "routes/datacenter.html#datacenter_enum",
                "domolibrary/routes/datacenter.py",
            ),
            "domolibrary.routes.datacenter.Datacenter_Filter_Field_Certification_Enum": (
                "routes/datacenter.html#datacenter_filter_field_certification_enum",
                "domolibrary/routes/datacenter.py",
            ),
            "domolibrary.routes.datacenter.Datacenter_Filter_Field_Enum": (
                "routes/datacenter.html#datacenter_filter_field_enum",
                "domolibrary/routes/datacenter.py",
            ),
            "domolibrary.routes.datacenter.Dataflow_Type_Filter_Enum": (
                "routes/datacenter.html#dataflow_type_filter_enum",
                "domolibrary/routes/datacenter.py",
            ),
            "domolibrary.routes.datacenter.SearchDatacenter_NoResultsFound": (
                "routes/datacenter.html#searchdatacenter_noresultsfound",
                "domolibrary/routes/datacenter.py",
            ),
            "domolibrary.routes.datacenter.SearchDatacenter_NoResultsFound.__init__": (
                "routes/datacenter.html#searchdatacenter_noresultsfound.__init__",
                "domolibrary/routes/datacenter.py",
            ),
            "domolibrary.routes.datacenter.ShareResource_Enum": (
                "routes/datacenter.html#shareresource_enum",
                "domolibrary/routes/datacenter.py",
            ),
            "domolibrary.routes.datacenter.generate_search_datacenter_account_body": (
                "routes/datacenter.html#generate_search_datacenter_account_body",
                "domolibrary/routes/datacenter.py",
            ),
            "domolibrary.routes.datacenter.generate_search_datacenter_body": (
                "routes/datacenter.html#generate_search_datacenter_body",
                "domolibrary/routes/datacenter.py",
            ),
            "domolibrary.routes.datacenter.generate_search_datacenter_filter": (
                "routes/datacenter.html#generate_search_datacenter_filter",
                "domolibrary/routes/datacenter.py",
            ),
            "domolibrary.routes.datacenter.generate_search_datacenter_filter_search_term": (
                "routes/datacenter.html#generate_search_datacenter_filter_search_term",
                "domolibrary/routes/datacenter.py",
            ),
            "domolibrary.routes.datacenter.get_connectors": (
                "routes/datacenter.html#get_connectors",
                "domolibrary/routes/datacenter.py",
            ),
            "domolibrary.routes.datacenter.get_lineage_upstream": (
                "routes/datacenter.html#get_lineage_upstream",
                "domolibrary/routes/datacenter.py",
            ),
            "domolibrary.routes.datacenter.search_datacenter": (
                "routes/datacenter.html#search_datacenter",
                "domolibrary/routes/datacenter.py",
            ),
            "domolibrary.routes.datacenter.share_resource": (
                "routes/datacenter.html#share_resource",
                "domolibrary/routes/datacenter.py",
            ),
        },
        "domolibrary.routes.dataflow": {
            "domolibrary.routes.dataflow.execute_dataflow": (
                "routes/dataflow.html#execute_dataflow",
                "domolibrary/routes/dataflow.py",
            ),
            "domolibrary.routes.dataflow.get_dataflow_by_id": (
                "routes/dataflow.html#get_dataflow_by_id",
                "domolibrary/routes/dataflow.py",
            ),
            "domolibrary.routes.dataflow.get_dataflow_by_id_and_version": (
                "routes/dataflow.html#get_dataflow_by_id_and_version",
                "domolibrary/routes/dataflow.py",
            ),
            "domolibrary.routes.dataflow.get_dataflow_execution_by_id": (
                "routes/dataflow.html#get_dataflow_execution_by_id",
                "domolibrary/routes/dataflow.py",
            ),
            "domolibrary.routes.dataflow.get_dataflow_execution_history": (
                "routes/dataflow.html#get_dataflow_execution_history",
                "domolibrary/routes/dataflow.py",
            ),
            "domolibrary.routes.dataflow.get_dataflow_versions": (
                "routes/dataflow.html#get_dataflow_versions",
                "domolibrary/routes/dataflow.py",
            ),
        },
        "domolibrary.routes.dataset": {
            "domolibrary.routes.dataset.DatasetNotFoundError": (
                "routes/dataset.html#datasetnotfounderror",
                "domolibrary/routes/dataset.py",
            ),
            "domolibrary.routes.dataset.DatasetNotFoundError.__init__": (
                "routes/dataset.html#datasetnotfounderror.__init__",
                "domolibrary/routes/dataset.py",
            ),
            "domolibrary.routes.dataset.QueryRequestError": (
                "routes/dataset.html#queryrequesterror",
                "domolibrary/routes/dataset.py",
            ),
            "domolibrary.routes.dataset.QueryRequestError.__init__": (
                "routes/dataset.html#queryrequesterror.__init__",
                "domolibrary/routes/dataset.py",
            ),
            "domolibrary.routes.dataset.ShareDataset_AccessLevelEnum": (
                "routes/dataset.html#sharedataset_accesslevelenum",
                "domolibrary/routes/dataset.py",
            ),
            "domolibrary.routes.dataset.ShareDataset_Error": (
                "routes/dataset.html#sharedataset_error",
                "domolibrary/routes/dataset.py",
            ),
            "domolibrary.routes.dataset.ShareDataset_Error.__init__": (
                "routes/dataset.html#sharedataset_error.__init__",
                "domolibrary/routes/dataset.py",
            ),
            "domolibrary.routes.dataset.UploadDataError": (
                "routes/dataset.html#uploaddataerror",
                "domolibrary/routes/dataset.py",
            ),
            "domolibrary.routes.dataset.UploadDataError.__init__": (
                "routes/dataset.html#uploaddataerror.__init__",
                "domolibrary/routes/dataset.py",
            ),
            "domolibrary.routes.dataset.alter_schema": (
                "routes/dataset.html#alter_schema",
                "domolibrary/routes/dataset.py",
            ),
            "domolibrary.routes.dataset.create": (
                "routes/dataset.html#create",
                "domolibrary/routes/dataset.py",
            ),
            "domolibrary.routes.dataset.delete": (
                "routes/dataset.html#delete",
                "domolibrary/routes/dataset.py",
            ),
            "domolibrary.routes.dataset.delete_partition_stage_1": (
                "routes/dataset.html#delete_partition_stage_1",
                "domolibrary/routes/dataset.py",
            ),
            "domolibrary.routes.dataset.delete_partition_stage_2": (
                "routes/dataset.html#delete_partition_stage_2",
                "domolibrary/routes/dataset.py",
            ),
            "domolibrary.routes.dataset.generate_create_dataset_body": (
                "routes/dataset.html#generate_create_dataset_body",
                "domolibrary/routes/dataset.py",
            ),
            "domolibrary.routes.dataset.generate_list_partitions_body": (
                "routes/dataset.html#generate_list_partitions_body",
                "domolibrary/routes/dataset.py",
            ),
            "domolibrary.routes.dataset.generate_share_dataset_payload": (
                "routes/dataset.html#generate_share_dataset_payload",
                "domolibrary/routes/dataset.py",
            ),
            "domolibrary.routes.dataset.get_dataset_by_id": (
                "routes/dataset.html#get_dataset_by_id",
                "domolibrary/routes/dataset.py",
            ),
            "domolibrary.routes.dataset.get_schema": (
                "routes/dataset.html#get_schema",
                "domolibrary/routes/dataset.py",
            ),
            "domolibrary.routes.dataset.index_dataset": (
                "routes/dataset.html#index_dataset",
                "domolibrary/routes/dataset.py",
            ),
            "domolibrary.routes.dataset.index_status": (
                "routes/dataset.html#index_status",
                "domolibrary/routes/dataset.py",
            ),
            "domolibrary.routes.dataset.list_partitions": (
                "routes/dataset.html#list_partitions",
                "domolibrary/routes/dataset.py",
            ),
            "domolibrary.routes.dataset.query_dataset_private": (
                "routes/dataset.html#query_dataset_private",
                "domolibrary/routes/dataset.py",
            ),
            "domolibrary.routes.dataset.query_dataset_public": (
                "routes/dataset.html#query_dataset_public",
                "domolibrary/routes/dataset.py",
            ),
            "domolibrary.routes.dataset.set_dataset_tags": (
                "routes/dataset.html#set_dataset_tags",
                "domolibrary/routes/dataset.py",
            ),
            "domolibrary.routes.dataset.share_dataset": (
                "routes/dataset.html#share_dataset",
                "domolibrary/routes/dataset.py",
            ),
            "domolibrary.routes.dataset.upload_dataset_stage_1": (
                "routes/dataset.html#upload_dataset_stage_1",
                "domolibrary/routes/dataset.py",
            ),
            "domolibrary.routes.dataset.upload_dataset_stage_2_df": (
                "routes/dataset.html#upload_dataset_stage_2_df",
                "domolibrary/routes/dataset.py",
            ),
            "domolibrary.routes.dataset.upload_dataset_stage_2_file": (
                "routes/dataset.html#upload_dataset_stage_2_file",
                "domolibrary/routes/dataset.py",
            ),
            "domolibrary.routes.dataset.upload_dataset_stage_3": (
                "routes/dataset.html#upload_dataset_stage_3",
                "domolibrary/routes/dataset.py",
            ),
        },
        "domolibrary.routes.grant": {
            "domolibrary.routes.grant.GetGrants_Error": (
                "routes/grant.html#getgrants_error",
                "domolibrary/routes/grant.py",
            ),
            "domolibrary.routes.grant.GetGrants_Error.__init__": (
                "routes/grant.html#getgrants_error.__init__",
                "domolibrary/routes/grant.py",
            ),
            "domolibrary.routes.grant.get_grants": (
                "routes/grant.html#get_grants",
                "domolibrary/routes/grant.py",
            ),
        },
        "domolibrary.routes.group": {
            "domolibrary.routes.group.GroupType_Enum": (
                "routes/group.html#grouptype_enum",
                "domolibrary/routes/group.py",
            ),
            "domolibrary.routes.group.Group_CRUD_Error": (
                "routes/group.html#group_crud_error",
                "domolibrary/routes/group.py",
            ),
            "domolibrary.routes.group.Group_CRUD_Error.__init__": (
                "routes/group.html#group_crud_error.__init__",
                "domolibrary/routes/group.py",
            ),
            "domolibrary.routes.group.SearchGroups_Error": (
                "routes/group.html#searchgroups_error",
                "domolibrary/routes/group.py",
            ),
            "domolibrary.routes.group.SearchGroups_Error.__init__": (
                "routes/group.html#searchgroups_error.__init__",
                "domolibrary/routes/group.py",
            ),
            "domolibrary.routes.group.create_group": (
                "routes/group.html#create_group",
                "domolibrary/routes/group.py",
            ),
            "domolibrary.routes.group.delete_groups": (
                "routes/group.html#delete_groups",
                "domolibrary/routes/group.py",
            ),
            "domolibrary.routes.group.generate_body_create_group": (
                "routes/group.html#generate_body_create_group",
                "domolibrary/routes/group.py",
            ),
            "domolibrary.routes.group.generate_body_update_group_membership": (
                "routes/group.html#generate_body_update_group_membership",
                "domolibrary/routes/group.py",
            ),
            "domolibrary.routes.group.generate_body_update_group_membership_entity": (
                "routes/group.html#generate_body_update_group_membership_entity",
                "domolibrary/routes/group.py",
            ),
            "domolibrary.routes.group.get_all_groups": (
                "routes/group.html#get_all_groups",
                "domolibrary/routes/group.py",
            ),
            "domolibrary.routes.group.get_group_by_id": (
                "routes/group.html#get_group_by_id",
                "domolibrary/routes/group.py",
            ),
            "domolibrary.routes.group.get_group_membership": (
                "routes/group.html#get_group_membership",
                "domolibrary/routes/group.py",
            ),
            "domolibrary.routes.group.get_group_owners": (
                "routes/group.html#get_group_owners",
                "domolibrary/routes/group.py",
            ),
            "domolibrary.routes.group.search_groups_by_name": (
                "routes/group.html#search_groups_by_name",
                "domolibrary/routes/group.py",
            ),
            "domolibrary.routes.group.toggle_system_group_visibility": (
                "routes/group.html#toggle_system_group_visibility",
                "domolibrary/routes/group.py",
            ),
            "domolibrary.routes.group.update_group": (
                "routes/group.html#update_group",
                "domolibrary/routes/group.py",
            ),
            "domolibrary.routes.group.update_group_membership": (
                "routes/group.html#update_group_membership",
                "domolibrary/routes/group.py",
            ),
        },
        "domolibrary.routes.instance_config": {
            "domolibrary.routes.instance_config.Allowlist_UnableToUpdate": (
                "routes/instance_config.html#allowlist_unabletoupdate",
                "domolibrary/routes/instance_config.py",
            ),
            "domolibrary.routes.instance_config.Allowlist_UnableToUpdate.__init__": (
                "routes/instance_config.html#allowlist_unabletoupdate.__init__",
                "domolibrary/routes/instance_config.py",
            ),
            "domolibrary.routes.instance_config.GetAppDomains_NotFound": (
                "routes/instance_config.html#getappdomains_notfound",
                "domolibrary/routes/instance_config.py",
            ),
            "domolibrary.routes.instance_config.GetAppDomains_NotFound.__init__": (
                "routes/instance_config.html#getappdomains_notfound.__init__",
                "domolibrary/routes/instance_config.py",
            ),
            "domolibrary.routes.instance_config.GetDomains_NotFound": (
                "routes/instance_config.html#getdomains_notfound",
                "domolibrary/routes/instance_config.py",
            ),
            "domolibrary.routes.instance_config.GetDomains_NotFound.__init__": (
                "routes/instance_config.html#getdomains_notfound.__init__",
                "domolibrary/routes/instance_config.py",
            ),
            "domolibrary.routes.instance_config.ToggleSocialUsers_Error": (
                "routes/instance_config.html#togglesocialusers_error",
                "domolibrary/routes/instance_config.py",
            ),
            "domolibrary.routes.instance_config.ToggleSocialUsers_Error.__init__": (
                "routes/instance_config.html#togglesocialusers_error.__init__",
                "domolibrary/routes/instance_config.py",
            ),
            "domolibrary.routes.instance_config.ToggleUserInvite_Error": (
                "routes/instance_config.html#toggleuserinvite_error",
                "domolibrary/routes/instance_config.py",
            ),
            "domolibrary.routes.instance_config.ToggleUserInvite_Error.__init__": (
                "routes/instance_config.html#toggleuserinvite_error.__init__",
                "domolibrary/routes/instance_config.py",
            ),
            "domolibrary.routes.instance_config.UpdateSSO_Error": (
                "routes/instance_config.html#updatesso_error",
                "domolibrary/routes/instance_config.py",
            ),
            "domolibrary.routes.instance_config.UpdateSSO_Error.__init__": (
                "routes/instance_config.html#updatesso_error.__init__",
                "domolibrary/routes/instance_config.py",
            ),
            "domolibrary.routes.instance_config.generate_sso_body": (
                "routes/instance_config.html#generate_sso_body",
                "domolibrary/routes/instance_config.py",
            ),
            "domolibrary.routes.instance_config.get_allowlist": (
                "routes/instance_config.html#get_allowlist",
                "domolibrary/routes/instance_config.py",
            ),
            "domolibrary.routes.instance_config.get_authorized_custom_app_domains": (
                "routes/instance_config.html#get_authorized_custom_app_domains",
                "domolibrary/routes/instance_config.py",
            ),
            "domolibrary.routes.instance_config.get_authorized_domains": (
                "routes/instance_config.html#get_authorized_domains",
                "domolibrary/routes/instance_config.py",
            ),
            "domolibrary.routes.instance_config.get_is_invite_social_users_enabled": (
                "routes/instance_config.html#get_is_invite_social_users_enabled",
                "domolibrary/routes/instance_config.py",
            ),
            "domolibrary.routes.instance_config.get_is_user_invite_notifications_enabled": (
                "routes/instance_config.html#get_is_user_invite_notifications_enabled",
                "domolibrary/routes/instance_config.py",
            ),
            "domolibrary.routes.instance_config.get_is_weekly_digest_enabled": (
                "routes/instance_config.html#get_is_weekly_digest_enabled",
                "domolibrary/routes/instance_config.py",
            ),
            "domolibrary.routes.instance_config.get_sso_config": (
                "routes/instance_config.html#get_sso_config",
                "domolibrary/routes/instance_config.py",
            ),
            "domolibrary.routes.instance_config.set_allowlist": (
                "routes/instance_config.html#set_allowlist",
                "domolibrary/routes/instance_config.py",
            ),
            "domolibrary.routes.instance_config.set_authorized_custom_app_domains": (
                "routes/instance_config.html#set_authorized_custom_app_domains",
                "domolibrary/routes/instance_config.py",
            ),
            "domolibrary.routes.instance_config.set_authorized_domains": (
                "routes/instance_config.html#set_authorized_domains",
                "domolibrary/routes/instance_config.py",
            ),
            "domolibrary.routes.instance_config.toggle_is_social_users_enabled": (
                "routes/instance_config.html#toggle_is_social_users_enabled",
                "domolibrary/routes/instance_config.py",
            ),
            "domolibrary.routes.instance_config.toggle_is_user_invite_enabled": (
                "routes/instance_config.html#toggle_is_user_invite_enabled",
                "domolibrary/routes/instance_config.py",
            ),
            "domolibrary.routes.instance_config.toggle_is_weekly_digest_enabled": (
                "routes/instance_config.html#toggle_is_weekly_digest_enabled",
                "domolibrary/routes/instance_config.py",
            ),
            "domolibrary.routes.instance_config.update_sso_config": (
                "routes/instance_config.html#update_sso_config",
                "domolibrary/routes/instance_config.py",
            ),
        },
        "domolibrary.routes.jupyter": {
            "domolibrary.routes.jupyter.JupyterAPI_Error": (
                "routes/jupyter.html#jupyterapi_error",
                "domolibrary/routes/jupyter.py",
            ),
            "domolibrary.routes.jupyter.JupyterAPI_Error.__init__": (
                "routes/jupyter.html#jupyterapi_error.__init__",
                "domolibrary/routes/jupyter.py",
            ),
            "domolibrary.routes.jupyter.JupyterAPI_WorkspaceStarted": (
                "routes/jupyter.html#jupyterapi_workspacestarted",
                "domolibrary/routes/jupyter.py",
            ),
            "domolibrary.routes.jupyter.JupyterAPI_WorkspaceStarted.__init__": (
                "routes/jupyter.html#jupyterapi_workspacestarted.__init__",
                "domolibrary/routes/jupyter.py",
            ),
            "domolibrary.routes.jupyter.generate_update_jupyter_body": (
                "routes/jupyter.html#generate_update_jupyter_body",
                "domolibrary/routes/jupyter.py",
            ),
            "domolibrary.routes.jupyter.generate_update_jupyter_body__directory": (
                "routes/jupyter.html#generate_update_jupyter_body__directory",
                "domolibrary/routes/jupyter.py",
            ),
            "domolibrary.routes.jupyter.generate_update_jupyter_body__ipynb": (
                "routes/jupyter.html#generate_update_jupyter_body__ipynb",
                "domolibrary/routes/jupyter.py",
            ),
            "domolibrary.routes.jupyter.generate_update_jupyter_body__new_content_path": (
                "routes/jupyter.html#generate_update_jupyter_body__new_content_path",
                "domolibrary/routes/jupyter.py",
            ),
            "domolibrary.routes.jupyter.generate_update_jupyter_body__text": (
                "routes/jupyter.html#generate_update_jupyter_body__text",
                "domolibrary/routes/jupyter.py",
            ),
            "domolibrary.routes.jupyter.generate_update_jupyter_body_factory": (
                "routes/jupyter.html#generate_update_jupyter_body_factory",
                "domolibrary/routes/jupyter.py",
            ),
            "domolibrary.routes.jupyter.generate_update_jupyter_body_factory.from_text": (
                "routes/jupyter.html#generate_update_jupyter_body_factory.from_text",
                "domolibrary/routes/jupyter.py",
            ),
            "domolibrary.routes.jupyter.get_content": (
                "routes/jupyter.html#get_content",
                "domolibrary/routes/jupyter.py",
            ),
            "domolibrary.routes.jupyter.get_content_recursive": (
                "routes/jupyter.html#get_content_recursive",
                "domolibrary/routes/jupyter.py",
            ),
            "domolibrary.routes.jupyter.get_jupyter_content": (
                "routes/jupyter.html#get_jupyter_content",
                "domolibrary/routes/jupyter.py",
            ),
            "domolibrary.routes.jupyter.get_jupyter_workspace_by_id": (
                "routes/jupyter.html#get_jupyter_workspace_by_id",
                "domolibrary/routes/jupyter.py",
            ),
            "domolibrary.routes.jupyter.get_jupyter_workspaces": (
                "routes/jupyter.html#get_jupyter_workspaces",
                "domolibrary/routes/jupyter.py",
            ),
            "domolibrary.routes.jupyter.get_workspace_auth_token_params": (
                "routes/jupyter.html#get_workspace_auth_token_params",
                "domolibrary/routes/jupyter.py",
            ),
            "domolibrary.routes.jupyter.parse_instance_service_location_and_prefix": (
                "routes/jupyter.html#parse_instance_service_location_and_prefix",
                "domolibrary/routes/jupyter.py",
            ),
            "domolibrary.routes.jupyter.start_jupyter_workspace": (
                "routes/jupyter.html#start_jupyter_workspace",
                "domolibrary/routes/jupyter.py",
            ),
            "domolibrary.routes.jupyter.update_jupyter_file": (
                "routes/jupyter.html#update_jupyter_file",
                "domolibrary/routes/jupyter.py",
            ),
        },
        "domolibrary.routes.page": {
            "domolibrary.routes.page.PageRetrieval_byId_Error": (
                "routes/page.html#pageretrieval_byid_error",
                "domolibrary/routes/page.py",
            ),
            "domolibrary.routes.page.PageRetrieval_byId_Error.__init__": (
                "routes/page.html#pageretrieval_byid_error.__init__",
                "domolibrary/routes/page.py",
            ),
            "domolibrary.routes.page.add_page_owner": (
                "routes/page.html#add_page_owner",
                "domolibrary/routes/page.py",
            ),
            "domolibrary.routes.page.delete_writelock": (
                "routes/page.html#delete_writelock",
                "domolibrary/routes/page.py",
            ),
            "domolibrary.routes.page.get_page_access_list": (
                "routes/page.html#get_page_access_list",
                "domolibrary/routes/page.py",
            ),
            "domolibrary.routes.page.get_page_access_test": (
                "routes/page.html#get_page_access_test",
                "domolibrary/routes/page.py",
            ),
            "domolibrary.routes.page.get_page_by_id": (
                "routes/page.html#get_page_by_id",
                "domolibrary/routes/page.py",
            ),
            "domolibrary.routes.page.get_page_definition": (
                "routes/page.html#get_page_definition",
                "domolibrary/routes/page.py",
            ),
            "domolibrary.routes.page.get_pages_adminsummary": (
                "routes/page.html#get_pages_adminsummary",
                "domolibrary/routes/page.py",
            ),
            "domolibrary.routes.page.put_writelock": (
                "routes/page.html#put_writelock",
                "domolibrary/routes/page.py",
            ),
            "domolibrary.routes.page.update_page_layout": (
                "routes/page.html#update_page_layout",
                "domolibrary/routes/page.py",
            ),
        },
        "domolibrary.routes.pdp": {
            "domolibrary.routes.pdp.CreatePolicy_Error": (
                "routes/pdp.html#createpolicy_error",
                "domolibrary/routes/pdp.py",
            ),
            "domolibrary.routes.pdp.CreatePolicy_Error.__init__": (
                "routes/pdp.html#createpolicy_error.__init__",
                "domolibrary/routes/pdp.py",
            ),
            "domolibrary.routes.pdp.PDP_NotRetrieved": (
                "routes/pdp.html#pdp_notretrieved",
                "domolibrary/routes/pdp.py",
            ),
            "domolibrary.routes.pdp.PDP_NotRetrieved.__init__": (
                "routes/pdp.html#pdp_notretrieved.__init__",
                "domolibrary/routes/pdp.py",
            ),
            "domolibrary.routes.pdp.SearchPDP_Error": (
                "routes/pdp.html#searchpdp_error",
                "domolibrary/routes/pdp.py",
            ),
            "domolibrary.routes.pdp.SearchPDP_Error.__init__": (
                "routes/pdp.html#searchpdp_error.__init__",
                "domolibrary/routes/pdp.py",
            ),
            "domolibrary.routes.pdp.create_policy": (
                "routes/pdp.html#create_policy",
                "domolibrary/routes/pdp.py",
            ),
            "domolibrary.routes.pdp.delete_policy": (
                "routes/pdp.html#delete_policy",
                "domolibrary/routes/pdp.py",
            ),
            "domolibrary.routes.pdp.generate_policy_body": (
                "routes/pdp.html#generate_policy_body",
                "domolibrary/routes/pdp.py",
            ),
            "domolibrary.routes.pdp.generate_policy_parameter_simple": (
                "routes/pdp.html#generate_policy_parameter_simple",
                "domolibrary/routes/pdp.py",
            ),
            "domolibrary.routes.pdp.get_pdp_policies": (
                "routes/pdp.html#get_pdp_policies",
                "domolibrary/routes/pdp.py",
            ),
            "domolibrary.routes.pdp.search_pdp_policies_by_name": (
                "routes/pdp.html#search_pdp_policies_by_name",
                "domolibrary/routes/pdp.py",
            ),
            "domolibrary.routes.pdp.toggle_pdp": (
                "routes/pdp.html#toggle_pdp",
                "domolibrary/routes/pdp.py",
            ),
            "domolibrary.routes.pdp.update_policy": (
                "routes/pdp.html#update_policy",
                "domolibrary/routes/pdp.py",
            ),
        },
        "domolibrary.routes.publish": {
            "domolibrary.routes.publish.accept_invite_by_id": (
                "routes/publish.html#accept_invite_by_id",
                "domolibrary/routes/publish.py",
            ),
            "domolibrary.routes.publish.accept_invite_by_id_v2": (
                "routes/publish.html#accept_invite_by_id_v2",
                "domolibrary/routes/publish.py",
            ),
            "domolibrary.routes.publish.create_publish_job": (
                "routes/publish.html#create_publish_job",
                "domolibrary/routes/publish.py",
            ),
            "domolibrary.routes.publish.generate_publish_body": (
                "routes/publish.html#generate_publish_body",
                "domolibrary/routes/publish.py",
            ),
            "domolibrary.routes.publish.get_publication_by_id": (
                "routes/publish.html#get_publication_by_id",
                "domolibrary/routes/publish.py",
            ),
            "domolibrary.routes.publish.get_subscription_invititations": (
                "routes/publish.html#get_subscription_invititations",
                "domolibrary/routes/publish.py",
            ),
            "domolibrary.routes.publish.get_subscription_summaries": (
                "routes/publish.html#get_subscription_summaries",
                "domolibrary/routes/publish.py",
            ),
            "domolibrary.routes.publish.refresh_publish_jobs": (
                "routes/publish.html#refresh_publish_jobs",
                "domolibrary/routes/publish.py",
            ),
            "domolibrary.routes.publish.search_publications": (
                "routes/publish.html#search_publications",
                "domolibrary/routes/publish.py",
            ),
            "domolibrary.routes.publish.udpate_publish_job": (
                "routes/publish.html#udpate_publish_job",
                "domolibrary/routes/publish.py",
            ),
        },
        "domolibrary.routes.role": {
            "domolibrary.routes.role.Role_CRUD_Error": (
                "routes/role.html#role_crud_error",
                "domolibrary/routes/role.py",
            ),
            "domolibrary.routes.role.Role_CRUD_Error.__init__": (
                "routes/role.html#role_crud_error.__init__",
                "domolibrary/routes/role.py",
            ),
            "domolibrary.routes.role.Role_NotRetrieved": (
                "routes/role.html#role_notretrieved",
                "domolibrary/routes/role.py",
            ),
            "domolibrary.routes.role.Role_NotRetrieved.__init__": (
                "routes/role.html#role_notretrieved.__init__",
                "domolibrary/routes/role.py",
            ),
            "domolibrary.routes.role.create_role": (
                "routes/role.html#create_role",
                "domolibrary/routes/role.py",
            ),
            "domolibrary.routes.role.delete_role": (
                "routes/role.html#delete_role",
                "domolibrary/routes/role.py",
            ),
            "domolibrary.routes.role.get_default_role": (
                "routes/role.html#get_default_role",
                "domolibrary/routes/role.py",
            ),
            "domolibrary.routes.role.get_role_by_id": (
                "routes/role.html#get_role_by_id",
                "domolibrary/routes/role.py",
            ),
            "domolibrary.routes.role.get_role_grants": (
                "routes/role.html#get_role_grants",
                "domolibrary/routes/role.py",
            ),
            "domolibrary.routes.role.get_role_membership": (
                "routes/role.html#get_role_membership",
                "domolibrary/routes/role.py",
            ),
            "domolibrary.routes.role.get_roles": (
                "routes/role.html#get_roles",
                "domolibrary/routes/role.py",
            ),
            "domolibrary.routes.role.role_membership_add_users": (
                "routes/role.html#role_membership_add_users",
                "domolibrary/routes/role.py",
            ),
            "domolibrary.routes.role.set_default_role": (
                "routes/role.html#set_default_role",
                "domolibrary/routes/role.py",
            ),
            "domolibrary.routes.role.set_role_grants": (
                "routes/role.html#set_role_grants",
                "domolibrary/routes/role.py",
            ),
            "domolibrary.routes.role.update_role_metadata": (
                "routes/role.html#update_role_metadata",
                "domolibrary/routes/role.py",
            ),
        },
        "domolibrary.routes.sandbox": {
            "domolibrary.routes.sandbox.Sandbox_ToggleSameInstancePromotion_Error": (
                "routes/sandbox.html#sandbox_togglesameinstancepromotion_error",
                "domolibrary/routes/sandbox.py",
            ),
            "domolibrary.routes.sandbox.Sandbox_ToggleSameInstancePromotion_Error.__init__": (
                "routes/sandbox.html#sandbox_togglesameinstancepromotion_error.__init__",
                "domolibrary/routes/sandbox.py",
            ),
            "domolibrary.routes.sandbox.get_is_allow_same_instance_promotion_enabled": (
                "routes/sandbox.html#get_is_allow_same_instance_promotion_enabled",
                "domolibrary/routes/sandbox.py",
            ),
            "domolibrary.routes.sandbox.get_repo_from_id": (
                "routes/sandbox.html#get_repo_from_id",
                "domolibrary/routes/sandbox.py",
            ),
            "domolibrary.routes.sandbox.get_shared_repos": (
                "routes/sandbox.html#get_shared_repos",
                "domolibrary/routes/sandbox.py",
            ),
            "domolibrary.routes.sandbox.toggle_allow_same_instance_promotion": (
                "routes/sandbox.html#toggle_allow_same_instance_promotion",
                "domolibrary/routes/sandbox.py",
            ),
        },
        "domolibrary.routes.stream": {
            "domolibrary.routes.stream.create_stream": (
                "routes/stream.html#create_stream",
                "domolibrary/routes/stream.py",
            ),
            "domolibrary.routes.stream.execute_stream": (
                "routes/stream.html#execute_stream",
                "domolibrary/routes/stream.py",
            ),
            "domolibrary.routes.stream.get_stream_by_id": (
                "routes/stream.html#get_stream_by_id",
                "domolibrary/routes/stream.py",
            ),
            "domolibrary.routes.stream.update_stream": (
                "routes/stream.html#update_stream",
                "domolibrary/routes/stream.py",
            ),
        },
        "domolibrary.routes.user": {
            "domolibrary.routes.user.DownloadAvatar_Error": (
                "routes/user.html#downloadavatar_error",
                "domolibrary/routes/user.py",
            ),
            "domolibrary.routes.user.DownloadAvatar_Error.__init__": (
                "routes/user.html#downloadavatar_error.__init__",
                "domolibrary/routes/user.py",
            ),
            "domolibrary.routes.user.GetUser_Error": (
                "routes/user.html#getuser_error",
                "domolibrary/routes/user.py",
            ),
            "domolibrary.routes.user.GetUser_Error.__init__": (
                "routes/user.html#getuser_error.__init__",
                "domolibrary/routes/user.py",
            ),
            "domolibrary.routes.user.ResetPassword_PasswordUsed": (
                "routes/user.html#resetpassword_passwordused",
                "domolibrary/routes/user.py",
            ),
            "domolibrary.routes.user.ResetPassword_PasswordUsed.__init__": (
                "routes/user.html#resetpassword_passwordused.__init__",
                "domolibrary/routes/user.py",
            ),
            "domolibrary.routes.user.SearchUser_NoResults": (
                "routes/user.html#searchuser_noresults",
                "domolibrary/routes/user.py",
            ),
            "domolibrary.routes.user.SearchUser_NoResults.__init__": (
                "routes/user.html#searchuser_noresults.__init__",
                "domolibrary/routes/user.py",
            ),
            "domolibrary.routes.user.UserProperty": (
                "routes/user.html#userproperty",
                "domolibrary/routes/user.py",
            ),
            "domolibrary.routes.user.UserProperty.__init__": (
                "routes/user.html#userproperty.__init__",
                "domolibrary/routes/user.py",
            ),
            "domolibrary.routes.user.UserProperty._value_to_list": (
                "routes/user.html#userproperty._value_to_list",
                "domolibrary/routes/user.py",
            ),
            "domolibrary.routes.user.UserProperty.to_json": (
                "routes/user.html#userproperty.to_json",
                "domolibrary/routes/user.py",
            ),
            "domolibrary.routes.user.UserProperty_Type": (
                "routes/user.html#userproperty_type",
                "domolibrary/routes/user.py",
            ),
            "domolibrary.routes.user.User_CrudError": (
                "routes/user.html#user_cruderror",
                "domolibrary/routes/user.py",
            ),
            "domolibrary.routes.user.User_CrudError.__init__": (
                "routes/user.html#user_cruderror.__init__",
                "domolibrary/routes/user.py",
            ),
            "domolibrary.routes.user.create_user": (
                "routes/user.html#create_user",
                "domolibrary/routes/user.py",
            ),
            "domolibrary.routes.user.delete_user": (
                "routes/user.html#delete_user",
                "domolibrary/routes/user.py",
            ),
            "domolibrary.routes.user.download_avatar": (
                "routes/user.html#download_avatar",
                "domolibrary/routes/user.py",
            ),
            "domolibrary.routes.user.generate_avatar_bytestr": (
                "routes/user.html#generate_avatar_bytestr",
                "domolibrary/routes/user.py",
            ),
            "domolibrary.routes.user.generate_patch_user_property_body": (
                "routes/user.html#generate_patch_user_property_body",
                "domolibrary/routes/user.py",
            ),
            "domolibrary.routes.user.get_all_users": (
                "routes/user.html#get_all_users",
                "domolibrary/routes/user.py",
            ),
            "domolibrary.routes.user.get_by_id": (
                "routes/user.html#get_by_id",
                "domolibrary/routes/user.py",
            ),
            "domolibrary.routes.user.process_v1_search_users": (
                "routes/user.html#process_v1_search_users",
                "domolibrary/routes/user.py",
            ),
            "domolibrary.routes.user.request_password_reset": (
                "routes/user.html#request_password_reset",
                "domolibrary/routes/user.py",
            ),
            "domolibrary.routes.user.reset_password": (
                "routes/user.html#reset_password",
                "domolibrary/routes/user.py",
            ),
            "domolibrary.routes.user.search_users": (
                "routes/user.html#search_users",
                "domolibrary/routes/user.py",
            ),
            "domolibrary.routes.user.search_users_by_email": (
                "routes/user.html#search_users_by_email",
                "domolibrary/routes/user.py",
            ),
            "domolibrary.routes.user.search_users_by_id": (
                "routes/user.html#search_users_by_id",
                "domolibrary/routes/user.py",
            ),
            "domolibrary.routes.user.search_virtual_user_by_subscriber_instance": (
                "routes/user.html#search_virtual_user_by_subscriber_instance",
                "domolibrary/routes/user.py",
            ),
            "domolibrary.routes.user.set_user_landing_page": (
                "routes/user.html#set_user_landing_page",
                "domolibrary/routes/user.py",
            ),
            "domolibrary.routes.user.update_user": (
                "routes/user.html#update_user",
                "domolibrary/routes/user.py",
            ),
            "domolibrary.routes.user.upload_avatar": (
                "routes/user.html#upload_avatar",
                "domolibrary/routes/user.py",
            ),
        },
        "domolibrary.routes.user_attributes": {
            "domolibrary.routes.user_attributes.UserAttributes_CRUD_Error": (
                "routes/user_attributes.html#userattributes_crud_error",
                "domolibrary/routes/user_attributes.py",
            ),
            "domolibrary.routes.user_attributes.UserAttributes_CRUD_Error.__init__": (
                "routes/user_attributes.html#userattributes_crud_error.__init__",
                "domolibrary/routes/user_attributes.py",
            ),
            "domolibrary.routes.user_attributes.UserAttributes_GET_Error": (
                "routes/user_attributes.html#userattributes_get_error",
                "domolibrary/routes/user_attributes.py",
            ),
            "domolibrary.routes.user_attributes.UserAttributes_GET_Error.__init__": (
                "routes/user_attributes.html#userattributes_get_error.__init__",
                "domolibrary/routes/user_attributes.py",
            ),
            "domolibrary.routes.user_attributes.UserAttributes_IssuerType": (
                "routes/user_attributes.html#userattributes_issuertype",
                "domolibrary/routes/user_attributes.py",
            ),
            "domolibrary.routes.user_attributes.clean_attribute_id": (
                "routes/user_attributes.html#clean_attribute_id",
                "domolibrary/routes/user_attributes.py",
            ),
            "domolibrary.routes.user_attributes.create_user_attribute": (
                "routes/user_attributes.html#create_user_attribute",
                "domolibrary/routes/user_attributes.py",
            ),
            "domolibrary.routes.user_attributes.delete_user_attribute": (
                "routes/user_attributes.html#delete_user_attribute",
                "domolibrary/routes/user_attributes.py",
            ),
            "domolibrary.routes.user_attributes.generate_create_user_attribute_body": (
                "routes/user_attributes.html#generate_create_user_attribute_body",
                "domolibrary/routes/user_attributes.py",
            ),
            "domolibrary.routes.user_attributes.get_user_attribute_by_id": (
                "routes/user_attributes.html#get_user_attribute_by_id",
                "domolibrary/routes/user_attributes.py",
            ),
            "domolibrary.routes.user_attributes.get_user_attributes": (
                "routes/user_attributes.html#get_user_attributes",
                "domolibrary/routes/user_attributes.py",
            ),
            "domolibrary.routes.user_attributes.update_user_attribute": (
                "routes/user_attributes.html#update_user_attribute",
                "domolibrary/routes/user_attributes.py",
            ),
        },
        "domolibrary.utils.DictDot": {
            "domolibrary.utils.DictDot.DictDot": (
                "utils/dictdot.html#dictdot",
                "domolibrary/utils/DictDot.py",
            ),
            "domolibrary.utils.DictDot.DictDot.__getattr__": (
                "utils/dictdot.html#dictdot.__getattr__",
                "domolibrary/utils/DictDot.py",
            ),
            "domolibrary.utils.DictDot.DictDot.__init__": (
                "utils/dictdot.html#dictdot.__init__",
                "domolibrary/utils/DictDot.py",
            ),
            "domolibrary.utils.DictDot.split_str_to_obj": (
                "utils/dictdot.html#split_str_to_obj",
                "domolibrary/utils/DictDot.py",
            ),
        },
        "domolibrary.utils.Image": {
            "domolibrary.utils.Image.Image.from_bytestr": (
                "utils/image.html#image.from_bytestr",
                "domolibrary/utils/Image.py",
            ),
            "domolibrary.utils.Image.Image.from_image_file": (
                "utils/image.html#image.from_image_file",
                "domolibrary/utils/Image.py",
            ),
            "domolibrary.utils.Image.are_same_image": (
                "utils/image.html#are_same_image",
                "domolibrary/utils/Image.py",
            ),
            "domolibrary.utils.Image.crop_square": (
                "utils/image.html#crop_square",
                "domolibrary/utils/Image.py",
            ),
            "domolibrary.utils.Image.handle_string_to_bytes_and_decode": (
                "utils/image.html#handle_string_to_bytes_and_decode",
                "domolibrary/utils/Image.py",
            ),
            "domolibrary.utils.Image.handle_string_to_bytes_and_encode": (
                "utils/image.html#handle_string_to_bytes_and_encode",
                "domolibrary/utils/Image.py",
            ),
            "domolibrary.utils.Image.isBase64": (
                "utils/image.html#isbase64",
                "domolibrary/utils/Image.py",
            ),
            "domolibrary.utils.Image.to_bytes": (
                "utils/image.html#to_bytes",
                "domolibrary/utils/Image.py",
            ),
        },
        "domolibrary.utils.chunk_execution": {
            "domolibrary.utils.chunk_execution.chunk_list": (
                "utils/chunk_execution.html#chunk_list",
                "domolibrary/utils/chunk_execution.py",
            ),
            "domolibrary.utils.chunk_execution.gather_with_concurrency": (
                "utils/chunk_execution.html#gather_with_concurrency",
                "domolibrary/utils/chunk_execution.py",
            ),
            "domolibrary.utils.chunk_execution.run_sequence": (
                "utils/chunk_execution.html#run_sequence",
                "domolibrary/utils/chunk_execution.py",
            ),
        },
        "domolibrary.utils.convert": {
            "domolibrary.utils.convert.ConcatDataframe_InvalidElement": (
                "utils/convert.html#concatdataframe_invalidelement",
                "domolibrary/utils/convert.py",
            ),
            "domolibrary.utils.convert.ConcatDataframe_InvalidElement.__init__": (
                "utils/convert.html#concatdataframe_invalidelement.__init__",
                "domolibrary/utils/convert.py",
            ),
            "domolibrary.utils.convert.InvalidEmail": (
                "utils/convert.html#invalidemail",
                "domolibrary/utils/convert.py",
            ),
            "domolibrary.utils.convert.InvalidEmail.__init__": (
                "utils/convert.html#invalidemail.__init__",
                "domolibrary/utils/convert.py",
            ),
            "domolibrary.utils.convert.concat_list_dataframe": (
                "utils/convert.html#concat_list_dataframe",
                "domolibrary/utils/convert.py",
            ),
            "domolibrary.utils.convert.convert_datetime_to_epoch_millisecond": (
                "utils/convert.html#convert_datetime_to_epoch_millisecond",
                "domolibrary/utils/convert.py",
            ),
            "domolibrary.utils.convert.convert_epoch_millisecond_to_datetime": (
                "utils/convert.html#convert_epoch_millisecond_to_datetime",
                "domolibrary/utils/convert.py",
            ),
            "domolibrary.utils.convert.convert_snake_to_pascal": (
                "utils/convert.html#convert_snake_to_pascal",
                "domolibrary/utils/convert.py",
            ),
            "domolibrary.utils.convert.convert_str_to_snake_case": (
                "utils/convert.html#convert_str_to_snake_case",
                "domolibrary/utils/convert.py",
            ),
            "domolibrary.utils.convert.convert_string_to_bool": (
                "utils/convert.html#convert_string_to_bool",
                "domolibrary/utils/convert.py",
            ),
            "domolibrary.utils.convert.test_valid_email": (
                "utils/convert.html#test_valid_email",
                "domolibrary/utils/convert.py",
            ),
        },
        "domolibrary.utils.read_creds_from_dotenv": {
            "domolibrary.utils.read_creds_from_dotenv.ReadCreds_EnvFileNotExist": (
                "utils/read_creds_from_dotenv.html#readcreds_envfilenotexist",
                "domolibrary/utils/read_creds_from_dotenv.py",
            ),
            "domolibrary.utils.read_creds_from_dotenv.ReadCreds_EnvFileNotExist.__init__": (
                "utils/read_creds_from_dotenv.html#readcreds_envfilenotexist.__init__",
                "domolibrary/utils/read_creds_from_dotenv.py",
            ),
            "domolibrary.utils.read_creds_from_dotenv.read_creds_from_dotenv": (
                "utils/read_creds_from_dotenv.html#read_creds_from_dotenv",
                "domolibrary/utils/read_creds_from_dotenv.py",
            ),
        },
        "domolibrary.utils.upload_data": {
            "domolibrary.utils.upload_data.loop_upload": (
                "utils/upload_data.html#loop_upload",
                "domolibrary/utils/upload_data.py",
            ),
            "domolibrary.utils.upload_data.upload_data": (
                "utils/upload_data.html#upload_data",
                "domolibrary/utils/upload_data.py",
            ),
        },
    },
}
